@@ -79,6 +79,7 @@ CTX::CTX() : gamepad(0)
 
   // need to initialize these too, since the corresponding opt_XXX routines use
   // the current value to detect changes
+  geom.hideCompounds = 1;
   mesh.changed = 0;
   mesh.qualityInf = mesh.qualitySup = mesh.qualityType = 0;
   mesh.radiusInf = mesh.radiusSup = 0;
@@ -86,7 +87,7 @@ CTX::CTX() : gamepad(0)
   mesh.prisms = mesh.pyramids = mesh.hexahedra = mesh.trihedra = 0;
   mesh.volumesEdges = mesh.volumesFaces = mesh.surfacesEdges = mesh.surfacesFaces = 0;
   mesh.volumesFaces = mesh.surfacesEdges = mesh.surfacesFaces = 0;
-  mesh.hoOptimize = mesh.smoothNormals = mesh.reverseAllNormals = 0;
+  mesh.hoOptimize = mesh.smoothNormals = 0;
   mesh.explode = mesh.angleSmoothNormals = 0.;
   mesh.numSubEdges = 0;
   mesh.colorCarousel = 0;
@@ -107,6 +108,7 @@ CTX::CTX() : gamepad(0)
   mesh.minCircPoints = mesh.order = 0;
   mesh.secondOrderLinear = mesh.secondOrderIncomplete = 0;
   mesh.preserveNumberingMsh2 = 1;
+  mesh.lightLines = 2;
 }
 
 CTX::~CTX()
