@@ -652,6 +652,8 @@ StringXNumber GeneralOptions_Number[] = {
     "Horizontal position (in pixels) of the (detached) menu tree" },
   { F|S, "MenuPositionY" , opt_general_menu_position1 , 400. ,
     "Vertical position (in pixels) of the (detached) menu tree" },
+  { F|O, "MeshDiscrete" , opt_general_meshdiscrete , 0. ,
+    "Mesh discrete surfaces through automatic parametrization (MUMPS required for efficiency) (0)" },
   { F|O, "MessageFontSize" , opt_general_message_fontsize , -1. ,
     "Size of the font in the message window (-1=automatic)" },
   { F|S, "MessageHeight" , opt_general_message_size , 300. ,
@@ -835,7 +837,7 @@ StringXNumber GeometryOptions_Number[] = {
     "Type of entity label (1=elementary number, 2=physical number)" },
   { F|O, "Light" , opt_geometry_light , 1. ,
     "Enable lighting for the geometry" },
-  { F|O, "LightTwoSide" , opt_geometry_light_two_side , 1. ,
+  { F|O, "LightTwoSide" , opt_geometry_light_two_side , 0. ,
     "Light both sides of surfaces (leads to slower rendering)" },
   { F|O, "Lines" , opt_geometry_lines , 1. ,
     "Display geometry curves?" },
@@ -1081,9 +1083,9 @@ StringXNumber MeshOptions_Number[] = {
     "Accuracy of evaluation of the LC field for 1D mesh generation" },
   { F|O, "Light" , opt_mesh_light , 1. ,
     "Enable lighting for the mesh" },
-  { F|O, "LightLines" , opt_mesh_light_lines , 1. ,
-    "Enable lighting for mesh lines (element edges)" },
-  { F|O, "LightTwoSide" , opt_mesh_light_two_side , 1. ,
+  { F|O, "LightLines" , opt_mesh_light_lines , 2. ,
+    "Enable lighting for mesh edges (0=no, 1=surfaces, 2=surfaces+volumes" },
+  { F|O, "LightTwoSide" , opt_mesh_light_two_side , 0. ,
     "Light both sides of surfaces (leads to slower rendering)" },
   { F|O, "Lines" , opt_mesh_lines , 0. ,
     "Display mesh lines (1D elements)?" },
@@ -1224,8 +1226,6 @@ StringXNumber MeshOptions_Number[] = {
     "7=conformal_fe" },
   { F|O, "RefineSteps" , opt_mesh_refine_steps , 10 ,
     "Number of refinement steps in the MeshAdapt-based 2D algorithms" },
-  { F|O, "ReverseAllNormals" , opt_mesh_reverse_all_normals , 0. ,
-    "Reverse all the mesh normals (for display)" },
 
   { F,   "SaveAll" , opt_mesh_save_all , 0. ,
     "Ignore Physical definitions and save all elements" },
@@ -1532,7 +1532,7 @@ StringXNumber ViewOptions_Number[] = {
     "Enable lighting for the view" },
   { F|O, "LightLines" , opt_view_light_lines , 1. ,
     "Light element edges" },
-  { F|O, "LightTwoSide" , opt_view_light_two_side , 1. ,
+  { F|O, "LightTwoSide" , opt_view_light_two_side , 0. ,
     "Light both sides of surfaces (leads to slower rendering)" },
   { F|O, "LineType" , opt_view_line_type , 0. ,
     "Display lines as solid color segments (0) or 3D cylinders (1)" },
