@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2015 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2016 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@geuz.org>.
+// bugs and problems to the public mailing list <gmsh@onelab.info>.
 
 #include "GmshConfig.h"
 
@@ -19,7 +19,7 @@
 #include <sstream>
 #include "GmshMessage.h"
 
-#if defined(HAVE_ONELAB) && defined(HAVE_POST) && !defined(HAVE_ONELAB2)
+#if defined(HAVE_ONELAB) && defined(HAVE_POST)
 
 #include "onelab.h"
 #include "OpenFile.h"
