@@ -1,13 +1,11 @@
-// Gmsh - Copyright (C) 1997-2015 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2016 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@geuz.org>.
+// bugs and problems to the public mailing list <gmsh@onelab.info>.
 
 #ifndef _HASH_H_
 #define _HASH_H_
 
-#include "GmshConfig.h"
-
 //--FNV hashing parameters
 
 #if defined(HAVE_64BIT_SIZE_T)
@@ -48,7 +46,7 @@ template <> struct Hash1FNV1a<1> {
 
 // Entry point
 template <int N> struct HashFNV1a {
-  static size_t eval(const void *const key) 
+  static size_t eval(const void *const key)
   {
     size_t hash = FNV_OFFSET_BASIS;
     return Hash1FNV1a<N>::eval(hash, static_cast<const unsigned char*>(key));
