@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2015 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2016 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@geuz.org>.
+// bugs and problems to the public mailing list <gmsh@onelab.info>.
 
 #ifndef _OPENFILE_H_
 #define _OPENFILE_H_
@@ -10,10 +10,10 @@
 
 int ParseFile(const std::string &fileName, bool close, bool warnIfMissing=false);
 void ParseString(const std::string &str, bool inCurrentModelDir=false);
-void OpenProject(const std::string &filename, bool setWindowTitle=true);
+void OpenProject(const std::string &filename);
 void OpenProjectMacFinder(const char *fileName);
 int MergeFile(const std::string &fileName, bool warnIfMissing=false,
-              bool setWindowTitle=true, bool setBoundingBox=true);
+              bool setBoundingBox=true, bool importPhysicalsInOnelab=true);
 int MergePostProcessingFile(const std::string &fileName, int showViews=2,
                             bool showLastStep=false, bool warnIfMissing=false);
 void ClearProject();
