@@ -149,6 +149,56 @@ class onelabGmshServer : public GmshServer{
   }
 };
 
+static std::string tryToGetGmshNumberOption(const std::string &name)
+{
+  std::string reply;
+  std::string::size_type dot = name.find('.');
+  if(dot != std::string::npos){
+    double val;
+    if(GmshGetOption(name.substr(0, dot), name.substr(dot + 1), val)){
+      onelab::number par(name, val);
+      reply = par.toChar();
+    }
+  }
+  return reply;
+}
+
+static std::string tryToGetGmshStringOption(const std::string &name)
+{
+  std::string reply;
+  std::string::size_type dot = name.find('.');
+  if(dot != std::string::npos){
+    std::string val;
+    if(GmshGetOption(name.substr(0, dot), name.substr(dot + 1), val)){
+      onelab::string par(name, val);
+      reply = par.toChar();
+    }
+  }
+  return reply;
+}
+
+static bool tryToSetGmshNumberOption(onelab::number &p)
+{
+  std::string name = p.getName();
+  std::string::size_type dot = name.find('.');
+  if(dot != std::string::npos){
+    double val = p.getValue();
+    return GmshSetOption(name.substr(0, dot), name.substr(dot + 1), val);
+  }
+  return false;
+}
+
+static bool tryToSetGmshStringOption(onelab::string &p)
+{
+  std::string name = p.getName();
+  std::string::size_type dot = name.find('.');
+  if(dot != std::string::npos){
+    std::string val = p.getValue();
+    return GmshSetOption(name.substr(0, dot), name.substr(dot + 1), val);
+  }
+  return false;
+}
+
 bool gmshLocalNetworkClient::receiveMessage(gmshLocalNetworkClient *master)
 {
   // receive a message on the associated GmshServer; 'master' is only used when
@@ -195,6 +245,7 @@ bool gmshLocalNetworkClient::receiveMessage(gmshLocalNetworkClient *master)
     }
     break;
   case GmshSocket::GMSH_PARAMETER:
+  case GmshSocket::GMSH_PARAMETER_WITHOUT_CHOICES:
   case GmshSocket::GMSH_PARAMETER_UPDATE:
     {
       std::string version, ptype, name;
@@ -205,36 +256,57 @@ bool gmshLocalNetworkClient::receiveMessage(gmshLocalNetworkClient *master)
       }
       else if(ptype == "number"){
         onelab::number p; p.fromChar(message);
-        if(type == GmshSocket::GMSH_PARAMETER_UPDATE){
-          std::vector<onelab::number> par; get(par, name);
-          if(par.size()) {
-            onelab::number y = p; p = par[0]; onelabUtils::updateNumber(p, y);
+        if(!tryToSetGmshNumberOption(p)){
+          if(type == GmshSocket::GMSH_PARAMETER_WITHOUT_CHOICES){
+            // append value to any choices already on the server
+            std::vector<onelab::number> par; get(par, name);
+            std::vector<double> c;
+            if(par.size()) c = par[0].getChoices();
+            c.push_back(p.getValue());
+            p.setChoices(c);
           }
-        }
-        set(p);
-        if(p.getName() == getName() + "/Progress"){
+          if(type == GmshSocket::GMSH_PARAMETER_UPDATE){
+            std::vector<onelab::number> par; get(par, name);
+            if(par.size()) {
+              onelab::number y = p; p = par[0]; onelabUtils::updateNumber(p, y);
+            }
+          }
+          set(p);
+          if(p.getName() == getName() + "/Progress"){
 #if defined(HAVE_FLTK)
-          if(FlGui::available())
-            FlGui::instance()->setProgress(p.getLabel().c_str(), p.getValue(),
-                                           p.getMin(), p.getMax());
+            if(FlGui::available())
+              FlGui::instance()->setProgress(p.getLabel().c_str(), p.getValue(),
+                                             p.getMin(), p.getMax());
 #endif
+          }
         }
       }
       else if(ptype == "string"){
         onelab::string p; p.fromChar(message);
-        if(type == GmshSocket::GMSH_PARAMETER_UPDATE){
-          std::vector<onelab::string> par; get(par, name);
-          if(par.size()){
-            onelab::string y = p; p = par[0]; onelabUtils::updateString(p,y);
+        if(!tryToSetGmshStringOption(p)){
+          if(type == GmshSocket::GMSH_PARAMETER_WITHOUT_CHOICES){
+            // append value to any choices already on the server
+            std::vector<onelab::string> par; get(par, name);
+            std::vector<std::string> c;
+            if(par.size()) c = par[0].getChoices();
+            c.push_back(p.getValue());
+            p.setChoices(c);
           }
-	}
-        set(p);
+          else if(type == GmshSocket::GMSH_PARAMETER_UPDATE){
+            std::vector<onelab::string> par; get(par, name);
+            if(par.size()){
+              onelab::string y = p; p = par[0]; onelabUtils::updateString(p,y);
+            }
+          }
+          set(p);
+        }
       }
       else
         Msg::Error("Unknown ONELAB parameter type: %s", ptype.c_str());
     }
     break;
   case GmshSocket::GMSH_PARAMETER_QUERY:
+  case GmshSocket::GMSH_PARAMETER_QUERY_WITHOUT_CHOICES:
     {
       std::string version, ptype, name, reply;
       onelab::parameter::getInfoFromChar(message, version, ptype, name);
@@ -243,12 +315,26 @@ bool gmshLocalNetworkClient::receiveMessage(gmshLocalNetworkClient *master)
                    onelab::parameter::version().c_str(), version.c_str());
       }
       else if(ptype == "number"){
-        std::vector<onelab::number> par; get(par, name);
-        if(par.size() == 1) reply = par[0].toChar();
+        std::vector<onelab::number> par;
+        if(type == GmshSocket::GMSH_PARAMETER_QUERY_WITHOUT_CHOICES)
+          getWithoutChoices(par, name);
+        else
+          get(par, name);
+        if(par.empty())
+          reply = tryToGetGmshNumberOption(name);
+        else
+          reply = par[0].toChar();
       }
       else if(ptype == "string"){
-        std::vector<onelab::string> par; get(par, name);
-        if(par.size() == 1) reply = par[0].toChar();
+        std::vector<onelab::string> par;
+        if(type == GmshSocket::GMSH_PARAMETER_QUERY_WITHOUT_CHOICES)
+          getWithoutChoices(par, name);
+        else
+          get(par, name);
+        if(par.empty())
+          reply = tryToGetGmshStringOption(name);
+        else
+          reply = par[0].toChar();
       }
       else
         Msg::Error("Unknown ONELAB parameter type in query: %s", ptype.c_str());
@@ -410,6 +496,7 @@ bool gmshLocalNetworkClient::receiveMessage(gmshLocalNetworkClient *master)
     break;
   default:
     Msg::Warning("Received unknown message type (%d)", type);
+    return false;
     break;
   }
 
