@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2015 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2016 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@geuz.org>.
+// bugs and problems to the public mailing list <gmsh@onelab.info>.
 
 #include <stdlib.h>
 #include <string>
@@ -11,9 +11,6 @@
 #include "Options.h"
 #include "PluginManager.h"
 #include "GModel.h"
-#if defined(HAVE_ONELAB2) && defined(__linux__)
-#include <X11/Xlib.h>
-#endif
 
 int main(int argc, char *argv[])
 {
@@ -36,13 +33,10 @@ int main(int argc, char *argv[])
   if(CTX::instance()->batch) {
     if(!Msg::GetGmshClient()) CTX::instance()->terminal = 1;
     GmshBatch();
-    GmshFinalize();
+    //GmshFinalize();
     Msg::Exit(0);
   }
 
   // Interactive Gmsh with FLTK GUI
-#if defined(HAVE_ONELAB2) && defined(__linux__)
-  XInitThreads();
-#endif
   return GmshFLTK(argc, argv);
 }
