@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2015 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2016 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@geuz.org>.
+// bugs and problems to the public mailing list <gmsh@onelab.info>.
 
 #include <FL/Fl_Box.H>
 #include <FL/Fl_Return_Button.H>
@@ -9,6 +9,7 @@
 #include "manipWindow.h"
 #include "paletteWindow.h"
 #include "graphicWindow.h"
+#include "openglWindow.h"
 #include "Options.h"
 #include "Context.h"
 
