@@ -917,6 +917,47 @@ static void multiple_selection_menu_cb(Fl_Widget *w, void *data)
   but->do_callback();
 }
 
+static void multiple_selection_menu_all_cb(Fl_Widget *w, void *data)
+{
+  Fl_Input_Choice *but = (Fl_Input_Choice*)data;
+  Fl_Menu_Button *menu = but->menubutton();
+  std::string val;
+  for (int i = 0; i < menu->size() - 1; i++) {
+    int mode = menu->mode(i);
+    if(mode & FL_MENU_TOGGLE){
+      if(mode & FL_MENU_DIVIDER)
+        menu->mode(i, FL_MENU_TOGGLE | FL_MENU_VALUE | FL_MENU_DIVIDER);
+      else
+        menu->mode(i, FL_MENU_TOGGLE | FL_MENU_VALUE);
+      const Fl_Menu_Item &item = menu->menu()[i];
+      if(item.label()){
+        if(val.size()) val += ", ";
+        val += item.label();
+      }
+    }
+  }
+  but->value(val.c_str());
+  but->do_callback();
+}
+
+static void multiple_selection_menu_none_cb(Fl_Widget *w, void *data)
+{
+  Fl_Input_Choice *but = (Fl_Input_Choice*)data;
+  Fl_Menu_Button *menu = but->menubutton();
+  std::string val;
+  for (int i = 0; i < menu->size() - 1; i++) {
+    int mode = menu->mode(i);
+    if(mode & FL_MENU_TOGGLE){
+      if(mode & FL_MENU_DIVIDER)
+        menu->mode(i, FL_MENU_TOGGLE | FL_MENU_DIVIDER);
+      else
+        menu->mode(i, FL_MENU_TOGGLE);
+    }
+  }
+  but->value("");
+  but->do_callback();
+}
+
 Fl_Widget *onelabGroup::_addParameterWidget(onelab::string &p, int ww, int hh,
                                             Fl_Tree_Item *n, bool highlight, Fl_Color c)
 {
@@ -941,7 +982,7 @@ Fl_Widget *onelabGroup::_addParameterWidget(onelab::string &p, int ww, int hh,
   }
 
   // non-editable value
-  if(p.getReadOnly()){
+  if(p.getReadOnly() && p.getKind() != "file"){
     Fl_Output *but = new Fl_Output(1, 1, ww, hh);
     but->value(p.getValue().c_str());
     but->align(FL_ALIGN_RIGHT | FL_ALIGN_CLIP);
@@ -975,21 +1016,29 @@ Fl_Widget *onelabGroup::_addParameterWidget(onelab::string &p, int ww, int hh,
   for(unsigned int j = 0; j < p.getChoices().size(); j++){
     char *str = strdup(p.getChoices()[j].c_str());
     _treeStrings.push_back(str);
-    bool divider = (p.getKind() == "file" &&
+    bool divider = ((p.getKind() == "file" || multipleSelection.size()) &&
                     j == p.getChoices().size() - 1);
     int choice = multipleSelection.size() ? FL_MENU_TOGGLE : 0;
     if(multipleSelection.size() > j && multipleSelection[j] == '1')
       choice |= FL_MENU_VALUE;
-    Fl_Menu_Item it = {str, 0, 0, 0, divider ? FL_MENU_DIVIDER : choice};
+    Fl_Menu_Item it = {str, 0, 0, 0, choice | (divider ? FL_MENU_DIVIDER : 0)};
     menu.push_back(it);
   }
-  if(p.getKind() == "file"){
-    Fl_Menu_Item it = {"Choose...", 0, onelab_input_choice_file_chooser_cb, (void*)n};
+  if(multipleSelection.size()){
+    Fl_Menu_Item it = {"Select All", 0, multiple_selection_menu_all_cb, but};
     menu.push_back(it);
-    Fl_Menu_Item it2 = {"Edit...", 0, onelab_input_choice_file_edit_cb, (void*)n};
+    Fl_Menu_Item it2 = {"Select None", 0, multiple_selection_menu_none_cb, but};
+    menu.push_back(it2);
+  }
+  if(p.getKind() == "file"){
+    if(!p.getReadOnly()){
+      Fl_Menu_Item it = {"Choose File...", 0, onelab_input_choice_file_chooser_cb, (void*)n};
+      menu.push_back(it);
+    }
+    Fl_Menu_Item it2 = {"Edit Selected File...", 0, onelab_input_choice_file_edit_cb, (void*)n};
     menu.push_back(it2);
     if(GuessFileFormatFromFileName(p.getValue()) >= 0){
-      Fl_Menu_Item it3 = {"Merge...", 0, onelab_input_choice_file_merge_cb, (void*)n};
+      Fl_Menu_Item it3 = {"Merge Selected File...", 0, onelab_input_choice_file_merge_cb, (void*)n};
       menu.push_back(it3);
     }
   }
@@ -1025,8 +1074,9 @@ static void view_group_cb(Fl_Widget *w, void *data)
 
 void onelabGroup::rebuildTree(bool deleteWidgets)
 {
-  FL_NORMAL_SIZE -= CTX::instance()->deltaFontSize;
+  setButtonVisibility();
 
+  FL_NORMAL_SIZE -= CTX::instance()->deltaFontSize;
   _computeWidths();
 
   std::set<std::string> closed = _getClosedGmshMenus();
@@ -1165,7 +1215,14 @@ void onelabGroup::setButtonVisibility()
 {
   std::vector<onelab::number> numbers;
   onelab::server::instance()->get(numbers);
-  bool showRun = onelab::server::instance()->getNumClients() > 1 || numbers.size();
+  bool visible = false;
+  for(unsigned int i = 0; i < numbers.size(); i++){
+    if(numbers[i].getVisible()){
+      visible = true;
+      break;
+    }
+  }
+  bool showRun = (onelab::server::instance()->getNumClients() > 1) || visible;
   if(CTX::instance()->solver.autoCheck){
     _butt[0]->hide();
     if(showRun)
@@ -1296,7 +1353,6 @@ void onelabGroup::rebuildSolverList()
     }
   }
 
-  setButtonVisibility();
   rebuildTree(true);
 }
 
