@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2015 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2016 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@geuz.org>.
+// bugs and problems to the public mailing list <gmsh@onelab.info>.
 
 #ifndef _ONELAB_GROUP_H_
 #define _ONELAB_GROUP_H_
@@ -36,10 +36,6 @@ class onelabGroup : public Fl_Group{
                                  Fl_Tree_Item *n, bool highlight, Fl_Color c);
   Fl_Widget *_addParameterWidget(onelab::string &p, int ww, int hh,
                                  Fl_Tree_Item *n, bool highlight, Fl_Color c);
-  Fl_Widget *_addParameterWidget(onelab::region &p, int ww, int hh,
-                                 Fl_Tree_Item *n, bool highlight, Fl_Color c);
-  Fl_Widget *_addParameterWidget(onelab::function &p, int ww, int hh,
-                                 Fl_Tree_Item *n, bool highlight, Fl_Color c);
   void _addMenu(const std::string &path, Fl_Callback *callback, void *data);
   void _addSolverMenu(int num);
   void _addViewMenu(int num);
