@@ -96,8 +96,10 @@ void GEdge::setMeshMaster(GEdge* ge,const std::vector<double>& tfo)
   SVector3 d01 = locXYZ0 - tfoXYZ1;
   SVector3 d11 = locXYZ1 - tfoXYZ1;
 
-  double tol = CTX::instance()->geom.tolerance;
-
+  double tol = CTX::instance()->geom.tolerance * CTX::instance()->lc;
+  
+  bool fwd = (d00.norm()*d11.norm() < d01.norm()*d10.norm());
+  
   if ((d00.norm() < tol) && (d11.norm() < tol)) {
     GEntity::setMeshMaster(ge,tfo);
     masterOrientation = 1;
@@ -107,6 +109,7 @@ void GEdge::setMeshMaster(GEdge* ge,const std::vector<double>& tfo)
     getEndVertex()  ->setMeshMaster(ge->getEndVertex()  ,tfo);
     return;
   }
+    
   if ((d01.norm() < tol) && (d10.norm() < tol)) {
     GEntity::setMeshMaster(ge,tfo);
     masterOrientation = -1;
@@ -116,10 +119,15 @@ void GEdge::setMeshMaster(GEdge* ge,const std::vector<double>& tfo)
     getEndVertex()  ->setMeshMaster(ge->getBeginVertex(),tfo);
     return;
   }
-
-  Msg::Error("Transformation from edge %d (%d-%d) to %d (%d-%d) is incorrect",
-             ge->tag(),ge->getBeginVertex()->tag(),ge->getEndVertex()->tag(),
-             this->tag(),this->getBeginVertex()->tag(),this->getEndVertex()->tag());
+  
+  Msg::Info("Error in transformation from edge %d (%d-%d) to %d (%d-%d)"
+            "(minimal transformed node distances %g %g, tolerance %g)",
+            ge->tag(),ge->getBeginVertex()->tag(),ge->getEndVertex()->tag(),
+            this->tag(),
+            this->getBeginVertex()->tag(),
+            this->getEndVertex()->tag(),
+            fwd ? d00.norm() : d01.norm(),
+            fwd ? d11.norm() : d10.norm(),tol);
 }
 
 void GEdge::reverse()
@@ -262,7 +270,7 @@ std::string GEdge::getAdditionalInfoString()
     sstream << " transfinite (" << meshAttributes.nbPointsTransfinite;
     int type = meshAttributes.typeTransfinite;
     if(std::abs(type) == 1)
-      sstream << ", progression " << sign(type) * meshAttributes.coeffTransfinite;
+      sstream << ", progression " << gmsh_sign(type) * meshAttributes.coeffTransfinite;
     else if(std::abs(type) == 2)
       sstream << ", bump " << meshAttributes.coeffTransfinite;
     sstream << ")";
@@ -477,7 +485,7 @@ bool GEdge::XYZToU(const double X, const double Y, const double Z,
   double uMin = uu.low();
   double uMax = uu.high();
 
-  SVector3 Q(X, Y, Z), P;
+  const SVector3 Q(X, Y, Z);
 
   double init[NumInitGuess];
 
@@ -490,6 +498,7 @@ bool GEdge::XYZToU(const double X, const double Y, const double Z,
     //err2 = 1.0;
     iter = 1;
 
+    SVector3 P = position(u);
     SVector3 dPQ = P - Q;
     err = dPQ.norm();
 
@@ -512,12 +521,12 @@ bool GEdge::XYZToU(const double X, const double Y, const double Z,
 
   if(relax > 1.e-2) {
     //    Msg::Info("point %g %g %g on edge %d : Relaxation factor = %g",
-    //              Q.x(), Q.y(), Q.z(), 0.75 * relax);
-    return XYZToU(Q.x(), Q.y(), Q.z(), u, 0.75 * relax);
+    //              X, Y, Z, 0.75 * relax);
+    return XYZToU(X, Y, Z, u, 0.75 * relax);
   }
 
   //  Msg::Error("Could not converge reparametrisation of point (%e,%e,%e) on edge %d",
-  //             Q.x(), Q.y(), Q.z(), tag());
+  //             X, Y, Z, tag());
   return false;
 }
 
