@@ -8,8 +8,9 @@
 
 #include "GEdge.h"
 
-struct GEdgeSigned
+class GEdgeSigned
 {
+ public:
   int _sign;
   GEdge *ge;
   GEdgeSigned(int i, GEdge *g) : _sign(i), ge(g) {}
@@ -22,7 +23,7 @@ struct GEdgeSigned
     return (_sign != 1) ? ge->getBeginVertex() : ge->getEndVertex();
   }
   void print() const;
-  int getSign(){ return _sign; }
+  int getSign() const { return _sign; }
 };
 
 class GEdgeLoop
