@@ -18,6 +18,7 @@
 #include "GaussLegendre1D.h"
 #include "Context.h"
 #include "OS.h"
+#include "discreteFace.h"
 
 #if defined(HAVE_MESH)
 #include "meshGFace.h"
@@ -1310,18 +1311,6 @@ double GFace::length(const SPoint2 &pt1, const SPoint2 &pt2, int nbQuadPoints)
   return L;
 }
 
-int GFace::poincareMesh()
-{
-  std::set<MEdge, Less_Edge> es;
-  std::set<MVertex*> vs;
-  for(unsigned int i = 0; i < getNumMeshElements(); i++){
-    MElement *e = getMeshElement(i);
-    for(int j = 0; j < e->getNumVertices(); j++) vs.insert(e->getVertex(j));
-    for(int j = 0; j < e->getNumEdges(); j++) es.insert(e->getEdge(j));
-  }
-  return vs.size() - es.size() + getNumMeshElements();
-}
-
 int GFace::genusGeom() const
 {
   int nSeams = 0;
@@ -1388,11 +1377,55 @@ bool GFace::fillPointCloud(double maxDist,
   return true;
 }
 
+
+#if defined(HAVE_MESH)
+static void meshCompound (GFace* gf, bool verbose) {
+
+  discreteFace *df = new discreteFace (gf->model(), gf->tag() + 100000);
+
+  std::set<int> ec;
+  for (unsigned int i=0;i<gf->_compound.size();i++){
+    GFace *c = (GFace*)gf->_compound[i];
+    std::list<GEdge*> edges = c->edges();
+    for (std::list<GEdge*> :: iterator it = edges.begin() ; it != edges.end(); ++it){
+      std::set<int>::iterator found = ec.find((*it)->tag());
+      if (found == ec.end())ec.insert((*it)->tag());
+      else ec.erase(found);
+    }
+    df->triangles.insert(df->triangles.end(), c->triangles.begin(),c->triangles.end());
+    df->mesh_vertices.insert(df->mesh_vertices.end(), c->mesh_vertices.begin(),c->mesh_vertices.end());
+    for (unsigned int j=0;j<c->triangles.size();j++)df->_CAD.push_back(c);
+    c->triangles.clear();
+    c->mesh_vertices.clear();
+  }
+  std::vector<int> cedges;
+  cedges.insert(cedges.begin(), ec.begin(), ec.end());
+  df->setBoundEdges(gf->model(), cedges);
+  df->createGeometry();
+  df->mesh(verbose);
+  delete df;
+}
+#endif
+
 void GFace::mesh(bool verbose)
 {
 #if defined(HAVE_MESH)
   meshGFace mesher;
   mesher(this, verbose);
+  if (!_compound.empty()){ // Some faces are meshed together
+    if (_compound[0] == this){ //  I'm the one that makes the compound job
+      bool ok = true;
+      for (unsigned int i=0;i<_compound.size();i++){
+	GFace *gf = (GFace*)_compound[i];
+	ok &= (gf->meshStatistics.status == GFace::DONE);
+      }
+      if (!ok)meshStatistics.status = GFace::PENDING;
+      else {
+	meshCompound(this, verbose);
+	return;
+      }
+    }
+  }
 #endif
 }
 
@@ -1446,68 +1479,6 @@ void GFace::moveToValidRange(SPoint2 &pt) const
   }
 }
 
-void GFace::addLayersOfQuads(int nLayers, GVertex *gv, double hmin, double ratio)
-{
-  SVector3 ez (0, 0, 1);
-  std::list<GEdgeLoop>::iterator it = edgeLoops.begin();
-  FILE *f = Fopen ("coucou.pos","w");
-  if(f) fprintf(f,"View \"\"{\n");
-  for (; it != edgeLoops.end(); ++it){
-    bool found = false;
-    // look if this edge loop has the GVertex as an endpoint
-    for (GEdgeLoop::iter it2 = it->begin(); it2 != it->end(); ++it2){
-      if (it2->ge->getBeginVertex() == gv || it2->ge->getEndVertex() == gv)
-	found = true;
-    }
-    // we found an edge loop with the GVertex that was specified
-    if (found){
-      // first build a list of edges in the parametric space
-      std::vector<std::pair<MVertex*,SPoint2> > contour;
-      for (GEdgeLoop::iter it2 = it->begin(); it2 != it->end(); ++it2){
-	GEdge *ge = it2->ge;
-	SPoint2 p[2];
-	if (it2->_sign == 1){
-	  for (unsigned int i = 0; i < ge->lines.size(); i++){
-	    reparamMeshEdgeOnFace(ge->lines[i]->getVertex(0), ge->lines[i]->getVertex(1),
-                                  this, p[0], p[1]);
-	    contour.push_back(std::make_pair(ge->lines[i]->getVertex(0), p[0]));
-	  }
-	}
-	else {
-	  for(int i = ge->lines.size() - 1; i >= 0; i--){
-	    reparamMeshEdgeOnFace(ge->lines[i]->getVertex(0), ge->lines[i]->getVertex(1),
-                                  this,p[0],p[1]);
-	    contour.push_back(std::make_pair(ge->lines[i]->getVertex(1),p[1]));
-	  }
-	}
-      }
-      double hlayer = hmin;
-      for (int j = 0; j < nLayers; j++){
-	for (unsigned int i = 0; i < contour.size(); i++){
-	  SPoint2 p0 = contour[(i+0) % contour.size()].second;
-	  SPoint2 p1 = contour[(i+1) % contour.size()].second;
-	  SPoint2 p2 = contour[(i+2) % contour.size()].second;
-	  SVector3 p0p1 (p1.x()-p0.x(),p1.y()-p0.y(),0.0);
-	  SVector3 p1p2 (p2.x()-p1.x(),p2.y()-p1.y(),0.0);
-	  SVector3 n01 = crossprod(ez,p0p1);
-	  SVector3 n12 = crossprod(ez,p1p2);
-	  SVector3 n = (n01+n12)*-0.5;
-	  n.normalize();
-	  double u = p1.x() + n.x() * hmin;
-	  double v = p1.y() + n.y() * hmin;
-	  GPoint gp = point(SPoint2(u,v));
-	  additionalVertices.push_back(new MFaceVertex(gp.x(),gp.y(),gp.z(),this,u,v));
-	  if(f) fprintf(f,"SP(%g, %g, 0){1};\n",gp.x(),gp.y());
-	}
-	hlayer *= ratio;
-	hmin += hlayer;
-      }
-      if(f) fprintf(f,"};\n");
-    }
-  }
-  if(f) fclose(f);
-}
-
 void GFace::relocateMeshVertices()
 {
   for(unsigned int i = 0; i < mesh_vertices.size(); i++){
@@ -1522,11 +1493,13 @@ void GFace::relocateMeshVertices()
   }
 }
 
-void GFace::setMeshMaster(GFace* master,const std::vector<double>& tfo)
+void GFace::setMeshMaster(GFace* master, const std::vector<double>& tfo)
 {
   std::list<GEdge*>::iterator eIter;
   std::list<GVertex*>::iterator vIter;
 
+  Msg::Info("Setting mesh master using transformation ");
+
   // list all vertices and construct vertex to edge correspondence for local edge
 
   std::set<GVertex*> l_vertices;
@@ -1601,15 +1574,13 @@ void GFace::setMeshMaster(GFace* master,const std::vector<double>& tfo)
 
     GVertex* m_vertex = *mvIter;
 
-    double xyzOri[4] = {m_vertex->x(),
-                        m_vertex->y(),
-                        m_vertex->z(),1};
+    SPoint3 xyzOri((*mvIter)->x(),(*mvIter)->y(),(*mvIter)->z());
     SPoint3 xyzTfo(0,0,0);
 
-    for (size_t i=0,ij=0;i<3;i++) {
-      for (size_t j=0;j<4;j++,ij++) {
-        xyzTfo[i] += tfo[ij] * xyzOri[j];
-      }
+    int idx = 0;
+    for (int i=0;i<3;i++) {
+      for (int j=0;j<3;j++) xyzTfo[i] += xyzOri[j] * tfo[idx++];
+      xyzTfo[i] += tfo[idx++];
     }
 
     GVertex* l_vertex = NULL;
@@ -1620,14 +1591,14 @@ void GFace::setMeshMaster(GFace* master,const std::vector<double>& tfo)
       SPoint3 xyz((*lvIter)->x(),(*lvIter)->y(),(*lvIter)->z());
       SVector3 dist = xyz - xyzTfo;
 
-      if (dist.norm() < CTX::instance()->geom.tolerance) {
+      if (dist.norm() < CTX::instance()->geom.tolerance * CTX::instance()->lc) {
         l_vertex = *lvIter;
         break;
       }
     }
 
     if (l_vertex==NULL) {
-      Msg::Error("Was not able to find corresponding node for %d "
+      Msg::Error("Was not able to find corresponding node %d "
                  "for periodic connection of surface %d to %d "
                  "using the specified transformation",
                  m_vertex->tag(),master->tag(),tag());
@@ -1672,10 +1643,15 @@ void GFace::setMeshMaster(GFace* master,const std::vector<double>& tfo)
       return;
     }
     GEdge* masterEdge = mv2eIter->second;
-    localEdge->setMeshMaster(masterEdge,tfo);
+
+    if (masterEdge->meshMaster() != localEdge) {
+      localEdge->setMeshMaster(masterEdge,tfo);
+      Msg::Info("Setting edge master %d - %d",
+                localEdge->tag(),
+                masterEdge->tag());
+    }
     gEdgeCounterparts[localEdge] = std::make_pair(masterEdge,sign);
   }
-
   // complete the information at the edge level
 
   edgeCounterparts   = gEdgeCounterparts;
@@ -1812,11 +1788,11 @@ void GFace::setMeshMaster(GFace* master,const std::map<int,int>& edgeCopies)
   std::vector<double> tfo(16);
 
   if (translation) {
-    Msg::Info("Periodic mesh translation found: dx = (%g,%g,%g)",
-              DX.x(), DX.y(), DX.z());
+    Msg::Info("Periodic mesh translation found between %d and %d: dx = (%g,%g,%g)",
+              tag(),master->tag(),DX.x(), DX.y(), DX.z());
 
     for (size_t i=0;i<16;i++) tfo[i] = 0;
-    for (size_t i=0;i<3;i++)  tfo[i*4+i] = 1;
+    for (size_t i=0;i<4;i++)  tfo[i*4+i] = 1;
     tfo[3]  = DX.x();
     tfo[7]  = DX.y();
     tfo[11] = DX.z();
@@ -1908,7 +1884,8 @@ void GFace::setMeshMaster(GFace* master,const std::map<int,int>& edgeCopies)
 
       for (int i=0;i<3;i++) tfo[i*4+3] =  origin[i];
       for (int i=0;i<3;i++) for (int j=0;j<3;j++) tfo[i*4+3] -= tfo[i*4+j] * origin[j];
-      for (int i=0;i<4;i++) tfo[12+i] = 0;
+      for (int i=0;i<3;i++) tfo[12+i] = 0;
+      tfo[15] = 1;
 
     }
     else {
