@@ -164,10 +164,11 @@ class GModel
  public:
   GModel(std::string name="");
   virtual ~GModel();
-
-
+// Required for python bindings on Windows
+#ifndef SWIG
   // the static list of all loaded models
   static std::vector<GModel*> list;
+# endif
 
   // return the current model, and sets the current model index if
   // index >= 0
