@@ -39,6 +39,13 @@ class MEdge {
   inline MVertex *getSortedVertex(const int i) const { return _v[int(_si[i])]; }
   inline MVertex *getMinVertex() const { return _v[int(_si[0])]; }
   inline MVertex *getMaxVertex() const { return _v[int(_si[1])]; }
+  
+  inline int computeCorrespondence(MEdge& other) {
+    if (other.getVertex(0) == _v[0] && other.getVertex(1) == _v[1]) return 1;
+    else if (other.getVertex(0) == _v[1] && other.getVertex(1) == _v[0]) return -1;
+    return 0;
+  }
+
   SVector3 scaledTangent() const
   {
     return SVector3(_v[1]->x() - _v[0]->x(),
