@@ -18,7 +18,6 @@
 #include "FuncSpaceData.h"
 #include "nodalBasis.h"
 #include "polynomialBasis.h"
-#include "MetricBasis.h"
 #include "GaussIntegration.h"
 
 class GModel;
@@ -48,13 +47,9 @@ class MElement
   MElement(int num=0, int part=0);
   virtual ~MElement(){}
 
-  // Create an element from tag
-  static MElement* createElement(int tag, const std::vector<MVertex*>&,
-                                 int num=0, int part=0);
-
   // set/get the tolerance for isInside() test
-  static void setTolerance(const double tol){ _isInsideTolerance = tol; }
-  static double getTolerance() { return _isInsideTolerance; }
+  static void setTolerance(const double tol);
+  static double getTolerance();
 
   // return the tag of the element
   virtual int getNum() const { return _num; }
@@ -219,7 +214,7 @@ class MElement
     signedInvCondNumRange(sICNMin, sICNMax);
     return sICNMin;
   }
-  double minAnisotropyMeasure(bool knownValid = false, bool reversedOk = false);
+  double minIsotropyMeasure(bool knownValid = false, bool reversedOk = false);
   double minScaledJacobian(bool knownValid = false, bool reversedOk = false);
   double specialQuality();
   double specialQuality2();
@@ -227,8 +222,6 @@ class MElement
   virtual void scaledJacRange(double &jmin, double &jmax, GEntity *ge = 0) const;
   virtual void idealJacRange(double &jmin, double &jmax, GEntity *ge = 0);
   virtual void signedInvCondNumRange(double &iCNMin, double &iCNMax, GEntity *ge = 0);
-  virtual double metricShapeMeasure();
-  virtual double metricShapeMeasure2();
 
   // get the radius of the inscribed circle/sphere if it exists,
   // otherwise get the minimum radius of all the circles/spheres
