@@ -8,19 +8,18 @@
 #include "GmshConfig.h"
 #include "MFace.h"
 #include "Numeric.h"
-#include "Context.h"
 
-bool compare (MVertex* v0, MVertex* v1) {return v0->getNum() < v1->getNum();}
+bool compare(MVertex* v0, MVertex* v1){ return v0->getNum() < v1->getNum(); }
 
 void sortVertices(const std::vector<MVertex*> &v, std::vector<char> &s)
 {
   if (v.size() == 3){
-    s.resize(3); 
-    if (v[0]->getNum() < v[1]->getNum() && 
+    s.resize(3);
+    if (v[0]->getNum() < v[1]->getNum() &&
 	v[0]->getNum() < v[2]->getNum() ){
       s[0] = 0; s[1] = 1; s[2] = 2;
     }
-    else if (v[1]->getNum() < v[0]->getNum() && 
+    else if (v[1]->getNum() < v[0]->getNum() &&
 	     v[1]->getNum() < v[2]->getNum() ){
       s[0] = 1; s[1] = 0; s[2] = 2;
     }
@@ -30,75 +29,27 @@ void sortVertices(const std::vector<MVertex*> &v, std::vector<char> &s)
 
     if (v[s[2]]->getNum() < v[s[1]]->getNum()){
       char temp = s[1];
-      s[1]=s[2];
-      s[2]=temp;
+      s[1] = s[2];
+      s[2] = temp;
     }
-    return;    
+    return;
   }
 
-  
   std::vector<MVertex*> sorted = v;
   std::sort(sorted.begin(), sorted.end(), compare);
   for(unsigned int i = 0; i < sorted.size(); i++)
     s.push_back(std::distance(v.begin(), std::find(v.begin(), v.end(), sorted[i])));
 }
 
-MFace::MFace(MVertex *v0, MVertex *v1, MVertex *v2, MVertex *v3) 
+MFace::MFace(MVertex *v0, MVertex *v1, MVertex *v2, MVertex *v3)
 {
   _v.push_back(v0);
-  if(CTX::instance()->mesh.reverseAllNormals){
-    // Note that we cannot simply change the normal computation,
-    // since OpenGL wants the normal to a polygon to be coherent
-    // with the ordering of its vertices
-    if(v3) _v.push_back(v3);
-    _v.push_back(v2);
-    _v.push_back(v1);
-  }
-  else{
-    _v.push_back(v1);
-    _v.push_back(v2);
-    if(v3) _v.push_back(v3);
-  }
+  _v.push_back(v1);
+  _v.push_back(v2);
+  if(v3) _v.push_back(v3);
   sortVertices(_v, _si);
-  /*// This is simply an unrolled insertion sort (hopefully fast).  Note that if
-  // _v[3] == 0, _v[3] is not sorted.
-  if(_v[1] < _v[0]) {
-    _si[0] = 1;
-    _si[1] = 0;
-  }
-  else {
-    _si[0] = 0;
-    _si[1] = 1;
-  }
-  if(_v[2] < _v[int(_si[1])]) {
-    _si[2] = _si[1];
-    if(_v[2] < _v[int(_si[0])]) {
-      _si[1] = _si[0];
-      _si[0] = 2;
-    }
-    else
-      _si[1] = 2;
-  }
-  else
-    _si[2] = 2;
-  if( _v[3] && _v[3] < _v[int(_si[2])]) {
-    _si[3] = _si[2];
-    if(_v[3] < _v[int(_si[1])]) {
-      _si[2] = _si[1];
-      if(_v[3] < _v[int(_si[0])]) {
-        _si[1] = _si[0];
-        _si[0] = 3;
-      }
-      else
-        _si[1] = 3;
-    }
-    else
-      _si[2] = 3;
-  }
-  else
-    _si[3] = 3;*/
-    
 }
+
 MFace::MFace(std::vector<MVertex*> v)
 {
   for(unsigned int i = 0; i < v.size(); i++)
@@ -115,13 +66,13 @@ SVector3 MFace::normal() const
   return SVector3(n[0], n[1], n[2]);
 }
 
-bool MFace::computeCorrespondence(const MFace &other, 
-                                  int &rotation, 
+bool MFace::computeCorrespondence(const MFace &other,
+                                  int &rotation,
                                   bool &swap) const
 {
   rotation = 0;
   swap = false;
-  
+
   if (*this == other) {
     for (int i = 0; i < getNumVertices(); i++) {
       if (_v[0] == other.getVertex(i)) {
@@ -135,5 +86,3 @@ bool MFace::computeCorrespondence(const MFace &other,
   }
   return false;
 }
-
-  
