@@ -83,11 +83,7 @@ class MQuadrangle : public MElement {
     Msg::Error("Could not get edge information for quadranglee %d", getNum());
   }
   virtual int getNumEdgesRep(bool curved){ return 4; }
-  virtual void getEdgeRep(bool curved, int num, double *x, double *y, double *z, SVector3 *n)
-  {
-    MEdge e(getEdge(num));
-    _getEdgeRep(e.getVertex(0), e.getVertex(1), x, y, z, n, 0);
-  }
+  virtual void getEdgeRep(bool curved, int num, double *x, double *y, double *z, SVector3 *n);
   virtual void getEdgeVertices(const int num, std::vector<MVertex*> &v) const
   {
     v.resize(2);
@@ -101,8 +97,7 @@ class MQuadrangle : public MElement {
     static const int f[2][3] = {
       {0, 1, 2}, {0, 2, 3}
     };
-    _getFaceRep(getVertex(f[num][0]), getVertex(f[num][1]), getVertex(f[num][2]),
-                x, y, z, n);
+    _getFaceRep(_v[f[num][0]], _v[f[num][1]], _v[f[num][2]], x, y, z, n);
   }
   virtual void getFaceVertices(const int num, std::vector<MVertex*> &v) const
   {
@@ -330,6 +325,7 @@ class MQuadrangle9 : public MQuadrangle {
   virtual int getTypeForMSH() const { return MSH_QUA_9; }
   virtual int getTypeForVTK() const { return 28; }
   virtual const char *getStringForPOS() const { return "SQ2"; }
+  virtual const char *getStringForBDF() const { return "CQUAD9"; }
   virtual const char *getStringForDIFF() const { return "ElmB9n2D"; }
   virtual const char *getStringForTOCHNOG() const { return "-quad9"; }
   virtual void reverse()
