@@ -8,6 +8,7 @@
 
 #include "MSubElement.h"
 #include "Numeric.h"
+#include "GModel.h"
 
 // MSubTetrahedron
 
@@ -17,6 +18,11 @@ MSubTetrahedron::~MSubTetrahedron()
   if(_base) delete _base;
 }
 
+void MSubTetrahedron::updateParent(GModel *gm)
+{
+  _orig=gm->getMeshElementByTag(_orig_N);
+}
+
 const nodalBasis* MSubTetrahedron::getFunctionSpace(int order, bool serendip) const
 {
   if(_orig) return _orig->getFunctionSpace(order, serendip);
@@ -209,6 +215,12 @@ MSubTriangle::~MSubTriangle()
   if(_base) delete _base;
 }
 
+void MSubTriangle::updateParent(GModel *gm)
+{
+  _orig=gm->getMeshElementByTag(_orig_N);
+}
+
+
 const nodalBasis* MSubTriangle::getFunctionSpace(int order, bool serendip) const
 {
   if(_orig) return _orig->getFunctionSpace(order, serendip);
@@ -447,6 +459,11 @@ MSubLine::~MSubLine()
   if(_base) delete _base;
 }
 
+void MSubLine::updateParent(GModel *gm)
+{
+  _orig=gm->getMeshElementByTag(_orig_N);
+}
+
 const nodalBasis* MSubLine::getFunctionSpace(int order, bool serendip) const
 {
   if(_orig) return _orig->getFunctionSpace(order, serendip);
@@ -676,6 +693,11 @@ MSubPoint::~MSubPoint()
   if(_base) delete _base;
 }
 
+void MSubPoint::updateParent(GModel *gm)
+{
+  _orig=gm->getMeshElementByTag(_orig_N);
+}
+
 const nodalBasis* MSubPoint::getFunctionSpace(int order, bool serendip) const
 {
   if(_orig) return _orig->getFunctionSpace(order, serendip);
