@@ -9,7 +9,6 @@
 #include "Context.h"
 #include "BasisFactory.h"
 
-
 #if defined(HAVE_MESH)
 #include "qualityMeasures.h"
 #include "meshGFaceDelaunayInsertion.h"
@@ -18,6 +17,28 @@
 
 #define SQU(a)      ((a)*(a))
 
+void MTetrahedron::getEdgeRep(bool curved, int num, double *x, double *y, double *z,
+                              SVector3 *n)
+{
+  // don't use MElement::_getEdgeRep: it's slow due to the creation of MFaces
+  MVertex *v0 = _v[edges_tetra(num, 0)];
+  MVertex *v1 = _v[edges_tetra(num, 1)];
+  x[0] = v0->x(); y[0] = v0->y(); z[0] = v0->z();
+  x[1] = v1->x(); y[1] = v1->y(); z[1] = v1->z();
+  if(CTX::instance()->mesh.lightLines > 1){
+    static const int vv[6] = {2, 0, 1, 1, 0, 2};
+    MVertex *v2 = _v[vv[num]];
+    SVector3 t1(x[1] - x[0], y[1] - y[0], z[1] - z[0]);
+    SVector3 t2(v2->x() - x[0], v2->y() - y[0], v2->z() - z[0]);
+    SVector3 normal = crossprod(t1, t2);
+    normal.normalize();
+    n[0] = n[1] = normal;
+  }
+  else{
+    n[0] = n[1] = SVector3(0., 0., 1.);
+  }
+}
+
 SPoint3 MTetrahedron::circumcenter()
 {
 #if defined(HAVE_MESH)
@@ -100,11 +121,13 @@ void MTetrahedron::xyz2uvw(double xyz[3], double uvw[3]) const
   sys3x3(mat, b, uvw, &det);
 }
 
-int MTetrahedron10::getNumEdgesRep(bool curved){
+int MTetrahedron10::getNumEdgesRep(bool curved)
+{
   return curved ? 6 * CTX::instance()->mesh.numSubEdges : 6;
 }
 
-int MTetrahedronN::getNumEdgesRep(bool curved){
+int MTetrahedronN::getNumEdgesRep(bool curved)
+{
   return curved ? 6 * CTX::instance()->mesh.numSubEdges : 6;
 }
 
@@ -154,11 +177,13 @@ void MTetrahedronN::getEdgeRep(bool curved, int num,
   else MTetrahedron::getEdgeRep(false, num, x, y, z, n);
 }
 
-int MTetrahedronN::getNumFacesRep(bool curved) {
+int MTetrahedronN::getNumFacesRep(bool curved)
+{
   return curved ? 4 * SQU(CTX::instance()->mesh.numSubEdges) : 4;
 }
 
-int MTetrahedron10::getNumFacesRep(bool curved) {
+int MTetrahedron10::getNumFacesRep(bool curved)
+{
   return curved ? 4 * SQU(CTX::instance()->mesh.numSubEdges) : 4;
 }
 
