@@ -34,7 +34,7 @@ class MVertexRTree{
     _rtree->RemoveAll();
     delete _rtree;
   }
-  int insert(MVertex *v, bool warnIfExists=false)
+  MVertex *insert(MVertex *v, bool warnIfExists=false)
   {
     MVertex *out;
     double _min[3] = {v->x() - _tol, v->y() - _tol, v->z() - _tol};
@@ -43,18 +43,19 @@ class MVertexRTree{
       _rtree->Insert(_min, _max, v);
       return 0;
     }
-    else if(warnIfExists){
-      Msg::Warning("Vertex %d (%.16g, %.16g, %.16g) already exists in the "
-                   "mesh with tolerance %g", v->getNum(),
-                   v->x(), v->y(), v->z(), _tol);
+    else{
+      if(warnIfExists)
+        Msg::Warning("Vertex %d (%.16g, %.16g, %.16g) already exists in the "
+                     "mesh with tolerance %g", v->getNum(),
+                     v->x(), v->y(), v->z(), _tol);
+      return out;
     }
-    return 1; // one vertex not inserted
   }
   int insert(std::vector<MVertex*> &v, bool warnIfExists=false)
   {
     int num = 0;
     for(unsigned int i = 0; i < v.size(); i++)
-      num += insert(v[i], warnIfExists);
+      num += (insert(v[i], warnIfExists) ? 1 : 0);
     return num; // number of vertices not inserted
   }
   MVertex *find(double x, double y, double z)
