@@ -7,6 +7,12 @@
 #include "discreteRegion.h"
 #include "MVertex.h"
 #include "Geo.h"
+#include "Context.h"
+
+#if defined(HAVE_MESH)
+#include "meshGRegion.h"
+#include "meshGRegionDelaunayInsertion.h"
+#endif
 
 discreteRegion::discreteRegion(GModel *model, int num) : GRegion(model, num)
 {
@@ -53,3 +59,32 @@ void discreteRegion::findFaces(std::map<MFace, std::vector<int>, Less_Face> &map
   }
 }
 
+void discreteRegion::remesh()
+{
+#if defined(HAVE_MESH)
+
+  bool classify = false;
+  if(CTX::instance()->mesh.oldRefinement){
+    insertVerticesInRegion(this, 2000000000, classify);
+  }
+  else{
+    insertVerticesInRegion(this, 0, classify);
+    void edgeBasedRefinement(const int numThreads, const int nptsatonce, GRegion *gr);
+    edgeBasedRefinement(1, 1, this);
+  }
+
+  // not functional yet: need boundaries
+  for(int i = 0; i < std::max(CTX::instance()->mesh.optimize,
+                              CTX::instance()->mesh.optimizeNetgen); i++){
+    if(CTX::instance()->mesh.optimize >= i){
+      printf("optimizing!\n");
+      optimizeMeshGRegionGmsh opt; opt(this, true);
+    }
+    if(CTX::instance()->mesh.optimizeNetgen >= i){
+      printf("optimizing netgen!\n");
+      optimizeMeshGRegionNetgen opt; opt(this, true);
+    }
+  }
+
+#endif
+}
