@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2015 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2016 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@geuz.org>.
+// bugs and problems to the public mailing list <gmsh@onelab.info>.
 
 #ifndef _DRAW_CONTEXT_H_
 #define _DRAW_CONTEXT_H_
@@ -132,7 +132,7 @@ class drawContext {
   enum RenderMode {GMSH_RENDER=1, GMSH_SELECT=2, GMSH_FEEDBACK=3};
   int render_mode; // current rendering mode
  public:
-  drawContext(openglWindow *window, drawTransform *transform=0);
+  drawContext(openglWindow *window=0, drawTransform *transform=0);
   ~drawContext();
   bool isHighResolution();
   void copyViewAttributes(drawContext *other)
