@@ -1198,22 +1198,22 @@ class Popen2 {
     HANDLE hChildStd_OUT_Wr, hChildStd_IN_Rd;
     PROCESS_INFORMATION piProcInfo;
     SECURITY_ATTRIBUTES saAttr;
-    saAttr.nLength = sizeof(SECURITY_ATTRIBUTES); 
-    saAttr.bInheritHandle = TRUE; 
-    saAttr.lpSecurityDescriptor = NULL; 
-    if (!CreatePipe(&_hIn, &hChildStd_OUT_Wr, &saAttr, 0)) 
-      Msg::Error("StdoutRd CreatePipe"); 
-    if (!CreatePipe(&hChildStd_IN_Rd, &_hOut, &saAttr, 0)) 
+    saAttr.nLength = sizeof(SECURITY_ATTRIBUTES);
+    saAttr.bInheritHandle = TRUE;
+    saAttr.lpSecurityDescriptor = NULL;
+    if (!CreatePipe(&_hIn, &hChildStd_OUT_Wr, &saAttr, 0))
+      Msg::Error("StdoutRd CreatePipe");
+    if (!CreatePipe(&hChildStd_IN_Rd, &_hOut, &saAttr, 0))
       Msg::Error("Stdin CreatePipe");
-    if (!CreatePipe(&_hIn, &hChildStd_OUT_Wr, &saAttr, 0)) 
-      Msg::Error("StdoutRd CreatePipe"); 
+    if (!CreatePipe(&_hIn, &hChildStd_OUT_Wr, &saAttr, 0))
+      Msg::Error("StdoutRd CreatePipe");
     if (!SetHandleInformation(_hIn, HANDLE_FLAG_INHERIT, 0))
       Msg::Error("Stdout SetHandleInformation");
     STARTUPINFO siStartInfo;
-    BOOL bSuccess = FALSE; 
+    BOOL bSuccess = FALSE;
     ZeroMemory( &piProcInfo, sizeof(PROCESS_INFORMATION) );
     ZeroMemory( &siStartInfo, sizeof(STARTUPINFO) );
-    siStartInfo.cb = sizeof(STARTUPINFO); 
+    siStartInfo.cb = sizeof(STARTUPINFO);
     siStartInfo.hStdError = GetStdHandle(STD_ERROR_HANDLE);
     siStartInfo.hStdOutput = hChildStd_OUT_Wr;
     siStartInfo.hStdInput = hChildStd_IN_Rd;
@@ -1301,7 +1301,7 @@ class ExternalProcessField : public Field
   Popen2 _pipes;
   void closePipes() {
     if (_pipes.started()) {
-      double xyz[3] = { 
+      double xyz[3] = {
         std::numeric_limits<double>::quiet_NaN(),
         std::numeric_limits<double>::quiet_NaN(),
         std::numeric_limits<double>::quiet_NaN() };
@@ -2199,7 +2199,6 @@ std::string BoundaryLayerField::getDescription()
 BoundaryLayerField::BoundaryLayerField()
 {
   hwall_n = .1;
-  hwall_t = .5;
   hfar = 1;
   ratio = 1.1;
   thickness = 1.e-2;
@@ -2207,32 +2206,25 @@ BoundaryLayerField::BoundaryLayerField()
   tgt_aniso_ratio = 1.e10;
   iRecombine = 0;
   iIntersect = 0;
-  options["NodesList"] = new FieldOptionList
-    (nodes_id, "Indices of nodes in the geometric model", &update_needed);
   options["EdgesList"] = new FieldOptionList
     (edges_id, "Indices of curves in the geometric model for which a boundary "
      "layer is needed", &update_needed);
-  options["FacesList"] = new FieldOptionList
-    (faces_id, "Indices of faces in the geometric model for which a boundary "
-     "layer is needed", &update_needed);
-  options["FansList"] = new FieldOptionList
-    (fans_id, "Indices of edges in the geometric model for which a fan "
-     "is created", &update_needed);
   options["FanNodesList"] = new FieldOptionList
     (fan_nodes_id, "Indices of vertices in the geometric model for which a fan "
      "is created", &update_needed);
+  options["NodesList"] = new FieldOptionList
+    (nodes_id, "Indices of vertices in the geometric model for which a BL "
+     "ends", &update_needed);
   options["Quads"] = new FieldOptionInt
     (iRecombine, "Generate recombined elements in the boundary layer");
   options["IntersectMetrics"] = new FieldOptionInt
     (iIntersect, "Intersect metrics of all faces");
   options["hwall_n"] = new FieldOptionDouble
     (hwall_n, "Mesh Size Normal to the The Wall");
-  //  options["fan_angle"] = new FieldOptionDouble
-  //    (fan_angle, "Threshold angle for creating a mesh fan in the boundary layer");
+  options["hwall_n_nodes"] = new FieldOptionListDouble
+    (hwall_n_nodes, "Mesh Size Normal to the The Wall at nodes (overwrite hwall_n when defined)");
   options["AnisoMax"] = new FieldOptionDouble
     (tgt_aniso_ratio, "Threshold angle for creating a mesh fan in the boundary layer");
-  options["hwall_t"] = new FieldOptionDouble
-    (hwall_t, "Mesh Size Tangent to the Wall");
   options["ratio"] = new FieldOptionDouble
     (ratio, "Size Ratio Between Two Successive Layers");
   options["hfar"] = new FieldOptionDouble
@@ -2249,23 +2241,19 @@ void BoundaryLayerField::removeAttractors()
   update_needed = true;
 }
 
-void BoundaryLayerField::setupFor1d(int iE) {
-
-  if (faces_id_saved.empty() &&
-      edges_id_saved.empty() &&
-      faces_id_saved.empty() ){     
-    faces_id_saved = faces_id;
+void BoundaryLayerField::setupFor1d(int iE)
+{
+  if (edges_id_saved.empty() ){
     edges_id_saved = edges_id;
     nodes_id_saved = nodes_id;
   }
 
   nodes_id.clear();
   edges_id.clear();
-  faces_id.clear();
 
   bool found = std::find(edges_id_saved.begin(), edges_id_saved.end(), iE) !=
     edges_id_saved.end();
-  
+
   if (!found) {
     GEdge *ge = GModel::current()->getEdgeByTag(iE);
     GVertex *gv0 = ge->getBeginVertex();
@@ -2282,67 +2270,50 @@ void BoundaryLayerField::setupFor1d(int iE) {
   removeAttractors();
 }
 
-
 void BoundaryLayerField::setupFor2d(int iF)
 {
-  /* preprocess data in the following way
-     remove GFaces from the attarctors (only used in 2D)
-     for edges and vertices
-  */
-  if (faces_id_saved.empty() &&
-      edges_id_saved.empty() &&
-      faces_id_saved.empty() ){     
-    faces_id_saved = faces_id;
+  // remove GFaces from the attractors (only used in 2D) for edges and vertices
+  if (edges_id_saved.empty()){
     edges_id_saved = edges_id;
     nodes_id_saved = nodes_id;
   }
 
   nodes_id.clear();
   edges_id.clear();
-  faces_id.clear();
-  
-  //    printf("have %d %d\n",faces_id_saved.size(),edges_id_saved.size());
-  
-  ///  FIXME :
-  /// NOT REALLY A NICE WAY TO DO IT (VERY AD HOC)
-  /// THIS COULD BE PART OF THE INPUT
-  /// OR (better) CHANGE THE PHILOSOPHY
-  
+
+  // FIXME :
+  // NOT REALLY A NICE WAY TO DO IT (VERY AD HOC)
+  // THIS COULD BE PART OF THE INPUT
+  // OR (better) CHANGE THE PHILOSOPHY
+
   GFace *gf = GModel::current()->getFaceByTag(iF);
   std::list<GEdge*> ed = gf->edges();
   std::list<GEdge*> embedded_edges = gf->embeddedEdges();
-  ed.insert(ed.begin(), embedded_edges.begin(),embedded_edges.end());
+  ed.insert(ed.begin(), embedded_edges.begin(), embedded_edges.end());
 
-  
-
-  //    printf("face %d has %d edges\n",iF,ed.size());
-  for (std::list<GEdge*>::iterator it = ed.begin();
-	 it != ed.end() ; ++it){
+  for (std::list<GEdge*>::iterator it = ed.begin(); it != ed.end() ; ++it){
     bool isIn = false;
     int iE = (*it)->tag();
     bool found = std::find(edges_id_saved.begin(), edges_id_saved.end(), iE) !=
       edges_id_saved.end();
-    //      printf("edges %d found %d\n",iE,found);
     // this edge is a BL Edge
     if (found){
       std::list<GFace*> fc = (*it)->faces();
-      // one only face --> 2D --> BL
-      if (fc.size() == 1) isIn = true;
+      int numf = 0;
+      for(std::list<GFace*>::iterator it = fc.begin(); it != fc.end(); it++){
+        if((*it)->meshAttributes.extrude &&
+           (*it)->meshAttributes.extrude->geo.Mode == EXTRUDED_ENTITY){
+          // ok
+        }
+        else{
+          numf++;
+        }
+      }
+      // one only face, or other faces are extruded --> 2D --> BL
+      if (numf <= 1) isIn = true;
       else {
-	// more than one face and
-	std::list<GFace*>::iterator itf = fc.begin();
-	bool found_this = std::find(faces_id_saved.begin(), faces_id_saved.end(), iF) !=
-	  faces_id_saved.end();
-	if (!found_this)isIn = true;
-	else {
-	  bool foundAll = true;
-	  for ( ; itf != fc.end() ; ++itf){
-	    int iF2 = (*itf)->tag();
-	    foundAll &= std::find(faces_id_saved.begin(), faces_id_saved.end(), iF2) !=
-	      faces_id_saved.end();
-	  }
-	  if(foundAll) isIn = true;
-	}
+	Msg::Error ("Only 2D Boundary Layers are supported (edge %d is adjacet to %d faces",
+                    iE, fc.size());
       }
     }
     if (isIn){
@@ -2351,13 +2322,7 @@ void BoundaryLayerField::setupFor2d(int iF)
       nodes_id.push_back ((*it)->getEndVertex()->tag());
     }
   }
-    // printf("face %d %d BL Edges\n", iF, (int)edges_id.size());
-  removeAttractors();
-}
 
-void BoundaryLayerField::setupFor3d()
-{
-  faces_id = faces_id_saved;
   removeAttractors();
 }
 
@@ -2372,35 +2337,27 @@ double BoundaryLayerField::operator() (double x, double y, double z, GEntity *ge
 	it != edges_id.end(); ++it) {
       _att_fields.push_back(new AttractorField(1,*it,300000));
     }
-    for(std::list<int>::iterator it = faces_id.begin();
-	it != faces_id.end(); ++it) {
-      _att_fields.push_back(new AttractorField(2,*it,1200));
-    }
     update_needed = false;
   }
 
-
   double dist = 1.e22;
   if (_att_fields.empty())return dist;
-  //  AttractorField *cc;
   for (std::list<AttractorField*>::iterator it = _att_fields.begin();
        it != _att_fields.end(); ++it){
     double cdist = (*(*it)) (x, y, z);
     if (cdist < dist){
-      //      cc = *it;
       dist = cdist;
     }
   }
 
   if (dist > thickness*ratio) return 1.e22;
   current_distance = dist;
-  //  const double dist = (*field) (x, y, z);
-  //  current_distance = dist;
+  // const double dist = (*field) (x, y, z);
+  // current_distance = dist;
   double lc = dist*(ratio-1) + hwall_n;
 
-  //  double lc =  hwall_n;
-  //  double lc = hwall_n * pow (ratio, dist / hwall_t);  
-  return std::min (hfar,lc);
+  // double lc =  hwall_n;
+  return std::min(hfar, lc);
 }
 
 // assume that the closest point is one of the model vertices
@@ -2452,10 +2409,9 @@ void BoundaryLayerField::operator() (AttractorField *cc, double dist,
   // (dist/hwall)*(ratio-1) + 1 = ratio^{m}
   // lc =  dist*(ratio-1) + hwall
 
-  const double ll1   = dist*(ratio-1) + hwall_n;
-  double lc_n  = std::min(ll1,hfar);
-  const double ll2   = dist*(ratio-1) + hwall_t;
-  double lc_t  = std::min(lc_n*CTX::instance()->mesh.anisoMax, std::min(ll2,hfar));
+  const double ll1 = dist*(ratio-1) + hwall_n;
+  double lc_n = std::min(ll1,hfar);
+  double lc_t = std::min(lc_n*CTX::instance()->mesh.anisoMax, hfar);
 
   lc_n = std::max(lc_n, CTX::instance()->mesh.lcMin);
   lc_n = std::min(lc_n, CTX::instance()->mesh.lcMax);
@@ -2535,10 +2491,6 @@ void BoundaryLayerField::operator() (double x, double y, double z,
 	it != edges_id.end(); ++it) {
       _att_fields.push_back(new AttractorField(1,*it,10000));
     }
-    for(std::list<int>::iterator it = faces_id.begin();
-	it != faces_id.end(); ++it) {
-      _att_fields.push_back(new AttractorField(2,*it,1200));
-    }
     update_needed = false;
   }
 
