@@ -16,11 +16,11 @@ Geuzaine and J.-F. Remacle with the understanding that his contribution shall be
 cited appropriately.
 
 All reused or original Gmsh code is Copyright (C) 1997-2014 C. Geuzaine,
-J.-F. Remacle Gmsh is available at: www.geuz.org/gmsh
+J.-F. Remacle Gmsh is available at: www.gmsh.info
 
 For Gmsh license information, see the LICENSE.txt file for license
 information. Please report all Gmsh bugs and problems to the public mailing list
-<gmsh@geuz.org>.
+<gmsh@onelab.info>.
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License, Version 2, as published by the Free
