@@ -3,7 +3,7 @@
 // See the LICENSE.txt file for license information. Please report all
 // bugs and problems to the public mailing list <gmsh@onelab.info>.
 
-#ifdef _OPENMP
+#if defined(_OPENMP)
 #include <omp.h>
 #endif
 
@@ -25,69 +25,67 @@
 #include "MTetrahedron.h"
 #include "meshGRegionLocalMeshMod.h"
 
-const int MEASURE_BARR = 0;
-
-#ifdef _HAVE_NUMA
+#if defined(_HAVE_NUMA)
 #include <numa.h>
 #endif
 
 //int Tet::in_sphere_counter = 0;
 
-
 struct HilbertSortB
 {
-// The code for generating table transgc
-// from: http://graphics.stanford.edu/~seander/bithacks.html.
+  // The code for generating table transgc from:
+  // http://graphics.stanford.edu/~seander/bithacks.html.
   int transgc[8][3][8];
   int tsb1mod3[8];
   int maxDepth;
   int Limit;
   SBoundingBox3d bbox ;
   void ComputeGrayCode(int n);
-  int Split(Vertex** vertices,
+  int Split(Vert** vertices,
 	    int arraysize,int GrayCode0,int GrayCode1,
 	    double BoundingBoxXmin, double BoundingBoxXmax,
 	    double BoundingBoxYmin, double BoundingBoxYmax,
 	    double BoundingBoxZmin, double BoundingBoxZmax);
-  void Sort(Vertex** vertices, int arraysize, int e, int d,
-	   double BoundingBoxXmin, double BoundingBoxXmax,
+  void Sort(Vert** vertices, int arraysize, int e, int d,
+            double BoundingBoxXmin, double BoundingBoxXmax,
             double BoundingBoxYmin, double BoundingBoxYmax,
-	   double BoundingBoxZmin, double BoundingBoxZmax, int depth);
-  HilbertSortB (int m = 0, int l=2) : maxDepth(m),Limit(l)
+            double BoundingBoxZmin, double BoundingBoxZmax, int depth);
+  HilbertSortB (int m = 0, int l=2) : maxDepth(m), Limit(l)
   {
     ComputeGrayCode(3);
   }
-  void MultiscaleSortHilbert(Vertex** vertices, int arraysize,
-			     int threshold, double ratio, int *depth, std::vector<int> &indices)
+  void MultiscaleSortHilbert(Vert** vertices, int arraysize,
+			     int threshold, double ratio, int *depth,
+                             std::vector<int> &indices)
   {
-    int middle;
-
-    middle = 0;
+    int middle = 0;
     if (arraysize >= threshold) {
       (*depth)++;
       middle = (int)(arraysize * ratio);
       MultiscaleSortHilbert(vertices, middle, threshold, ratio, depth, indices);
     }
     indices.push_back(middle);
-    //    printf("chunk starts at %d and size %d\n",middle, arraysize - middle);
-    Sort (&(vertices[middle]),arraysize - middle,0,0,
-	  bbox.min().x(),bbox.max().x(),
-	  bbox.min().y(),bbox.max().y(),
-	  bbox.min().z(),bbox.max().z(),0);
+    // printf("chunk starts at %d and size %d\n",middle, arraysize - middle);
+    Sort(&(vertices[middle]),arraysize - middle,0,0,
+         bbox.min().x(),bbox.max().x(),
+         bbox.min().y(),bbox.max().y(),
+         bbox.min().z(),bbox.max().z(),0);
   }
-  void Apply (std::vector<Vertex*> &v, std::vector<int> &indices)
+  void Apply(std::vector<Vert*> &v, std::vector<int> &indices)
   {
-    for (size_t i=0;i<v.size();i++){
-      Vertex *pv = v[i];
-      bbox += SPoint3(pv->x(),pv->y(),pv->z());
+    indices.clear();
+    if(v.empty()) return;
+    for (size_t i = 0; i < v.size(); i++){
+      Vert *pv = v[i];
+      bbox += SPoint3(pv->x(), pv->y(), pv->z());
     }
     bbox *= 1.01;
-    Vertex**pv = &v[0];
+    Vert **pv = &v[0];
     int depth;
     indices.clear();
-    MultiscaleSortHilbert(pv, (int)v.size(), 64, .125,&depth,indices);
+    MultiscaleSortHilbert(pv, (int)v.size(), 64, .125, &depth, indices);
     indices.push_back(v.size());
-    //    printf("depth = %d\n",depth);
+    // printf("depth = %d\n",depth);
   }
 };
 
@@ -136,14 +134,13 @@ void HilbertSortB::ComputeGrayCode(int n)
   }
 }
 
-
-int HilbertSortB::Split(Vertex** vertices,
+int HilbertSortB::Split(Vert** vertices,
 		       int arraysize,int GrayCode0,int GrayCode1,
 		       double BoundingBoxXmin, double BoundingBoxXmax,
                        double BoundingBoxYmin, double BoundingBoxYmax,
 		       double BoundingBoxZmin, double BoundingBoxZmax)
 {
-  Vertex* swapvert;
+  Vert* swapvert;
   int axis, d;
   double split;
   int i, j;
@@ -188,7 +185,8 @@ int HilbertSortB::Split(Vertex** vertices,
       vertices[j] = swapvert;
       // Continue patitioning the array;
     } while (true);
-  } else {
+  }
+  else {
     do {
       for (; i < arraysize; i++) {
         if (vertices[i]->point()[axis] <= split) break;
@@ -211,7 +209,7 @@ int HilbertSortB::Split(Vertex** vertices,
 
 // The sorting code is inspired by Tetgen 1.5
 
-void HilbertSortB::Sort(Vertex** vertices, int arraysize, int e, int d,
+void HilbertSortB::Sort(Vert** vertices, int arraysize, int e, int d,
 		       double BoundingBoxXmin, double BoundingBoxXmax,
                        double BoundingBoxYmin, double BoundingBoxYmax,
 		       double BoundingBoxZmin, double BoundingBoxZmax, int depth)
@@ -302,13 +300,14 @@ void HilbertSortB::Sort(Vertex** vertices, int arraysize, int e, int d,
   }
 }
 
-void SortHilbert (std::vector<Vertex*>& v, std::vector<int> &indices)
+void SortHilbert (std::vector<Vert*>& v, std::vector<int> &indices)
 {
   HilbertSortB h(1000);
   h.Apply(v, indices);
 }
 
-void computeAdjacencies (Tet *t, int iFace, connContainer &faceToTet){
+void computeAdjacencies (Tet *t, int iFace, connContainer &faceToTet)
+{
   conn c (t->getFace(iFace), iFace, t);
   connContainer::iterator it = std::find(faceToTet.begin(),faceToTet.end(),c);
   if (it == faceToTet.end()){
@@ -324,12 +323,10 @@ void computeAdjacencies (Tet *t, int iFace, connContainer &faceToTet){
 /***********************************************************************
   Local mesh modifications
 
-  edgeSwap , faceSwap , 
+  edgeSwap , faceSwap ,
 
 ************************************************************************/
 
-
-
 /***********************************************************************
   Compute all tets surrounding an edge
 ************************************************************************/
@@ -337,8 +334,8 @@ void computeAdjacencies (Tet *t, int iFace, connContainer &faceToTet){
 static int edges[6][2] =    {{0,1},{0,2},{0,3},{1,2},{1,3},{2,3}};
 static int efaces[6][2] =   {{0,2},{0,1},{1,2},{0,3},{2,3},{1,3}};
 static int faces[4][3] = {{0,1,2},{0,2,3},{0,1,3},{1,2,3}};
-static int vnofaces[4] = {3,1,2,0};
-static int vFac[4][3] = {{0,1,2},{0,2,3},{0,1,3},{1,2,3}};
+//static int vnofaces[4] = {3,1,2,0};
+//static int vFac[4][3] = {{0,1,2},{0,2,3},{0,1,3},{1,2,3}};
 
 static void computeNeighboringTetsOfACavity(const std::vector<Tet*> &cavity,
 					    std::vector<Tet*> &outside)
@@ -355,26 +352,26 @@ static void computeNeighboringTetsOfACavity(const std::vector<Tet*> &cavity,
   }
 }
 
-static bool buildEdgeCavity(Tet *t, int iLocalEdge, 
-			    Vertex **v1, Vertex **v2,
-			    std::vector<Tet*> &cavity, 
+static bool buildEdgeCavity(Tet *t, int iLocalEdge,
+			    Vert **v1, Vert **v2,
+			    std::vector<Tet*> &cavity,
 			    std::vector<Tet*> &outside,
-			    std::vector<Vertex*> &ring)
+			    std::vector<Vert*> &ring)
 {
   cavity.clear();
   ring.clear();
 
   *v1 = t->V[edges[iLocalEdge][0]];
   *v2 = t->V[edges[iLocalEdge][1]];
-  
+
   // the 5 - i th edge contains the other 2 points of the tet
-  Vertex *lastinring = t->V[edges[5 - iLocalEdge][0]];
+  Vert *lastinring = t->V[edges[5 - iLocalEdge][0]];
   ring.push_back(lastinring);
   cavity.push_back(t);
 
   while (1){
-    Vertex *ov1 = t->V[edges[5 - iLocalEdge][0]];
-    Vertex *ov2 = t->V[edges[5 - iLocalEdge][1]];
+    Vert *ov1 = t->V[edges[5 - iLocalEdge][0]];
+    Vert *ov2 = t->V[edges[5 - iLocalEdge][1]];
     int K = ov1 == lastinring ? 1 : 0;
     lastinring = ov1 == lastinring ? ov2 : ov1;
     // look in the 2 faces sharing this edge the one that has vertex
@@ -397,8 +394,8 @@ static bool buildEdgeCavity(Tet *t, int iLocalEdge,
     cavity.push_back(t);
     iLocalEdge = -1;
     for (int i = 0; i < 6; i++){
-      Vertex *a = t->V[edges[i][0]];
-      Vertex *b = t->V[edges[i][1]];
+      Vert *a = t->V[edges[i][0]];
+      Vert *b = t->V[edges[i][1]];
       if ((a == *v1 && b == *v2) || (a == *v2 && b == *v1)){
         iLocalEdge = i;
         break;
@@ -419,8 +416,8 @@ bool edgeSwap(Tet *tet, int iLocalEdge,  tetContainer &T, int myThread)
 {
   std::vector<Tet*> cavity;
   std::vector<Tet*> outside;
-  std::vector<Vertex*> ring;
-  Vertex *v1, *v2;
+  std::vector<Vert*> ring;
+  Vert *v1, *v2;
 
   bool closed = buildEdgeCavity(tet, iLocalEdge, &v1, &v2, cavity, outside, ring);
 
@@ -438,17 +435,17 @@ bool edgeSwap(Tet *tet, int iLocalEdge,  tetContainer &T, int myThread)
 
   double tetQualityRef = 1.e22;
   for (unsigned int i = 0; i < cavity.size(); i++){
-    Vertex *vx0 = cavity[i]->V[0];
-    Vertex *vx1 = cavity[i]->V[1];
-    Vertex *vx2 = cavity[i]->V[2];
-    Vertex *vx3 = cavity[i]->V[3];
+    Vert *vx0 = cavity[i]->V[0];
+    Vert *vx1 = cavity[i]->V[1];
+    Vert *vx2 = cavity[i]->V[2];
+    Vert *vx3 = cavity[i]->V[3];
     double volume = robustPredicates::orient3d((double*)vx0, (double*)vx1, (double*)vx2, (double*)vx3);
-    const double a  = 
+    const double a  =
       SQR (vx0->x() - vx1->x()) + SQR (vx0->y() - vx1->y()) + SQR (vx0->z() - vx1->z()) +
-      SQR (vx0->x() - vx2->x()) + SQR (vx0->y() - vx2->y()) + SQR (vx0->z() - vx2->z()) + 
-      SQR (vx0->x() - vx3->x()) + SQR (vx0->y() - vx3->y()) + SQR (vx0->z() - vx3->z()) + 
-      SQR (vx1->x() - vx2->x()) + SQR (vx1->y() - vx2->y()) + SQR (vx1->z() - vx2->z()) + 
-      SQR (vx1->x() - vx3->x()) + SQR (vx1->y() - vx3->y()) + SQR (vx1->z() - vx3->z()) + 
+      SQR (vx0->x() - vx2->x()) + SQR (vx0->y() - vx2->y()) + SQR (vx0->z() - vx2->z()) +
+      SQR (vx0->x() - vx3->x()) + SQR (vx0->y() - vx3->y()) + SQR (vx0->z() - vx3->z()) +
+      SQR (vx1->x() - vx2->x()) + SQR (vx1->y() - vx2->y()) + SQR (vx1->z() - vx2->z()) +
+      SQR (vx1->x() - vx3->x()) + SQR (vx1->y() - vx3->y()) + SQR (vx1->z() - vx3->z()) +
       SQR (vx2->x() - vx3->x()) + SQR (vx2->y() - vx3->y()) + SQR (vx2->z() - vx3->z()) ;
     tetQualityRef = std::min(tetQualityRef, volume / a);
   }
@@ -462,16 +459,16 @@ bool edgeSwap(Tet *tet, int iLocalEdge,  tetContainer &T, int myThread)
     int p3 = sp.triangles[i][2];
     const double volume1 = robustPredicates::orient3d((double*)ring[p1], (double*)ring[p2], (double*)ring[p3], (double*) v1);
     const double volume2 = robustPredicates::orient3d((double*)ring[p1], (double*)ring[p2], (double*)ring[p3], (double*) v2);
-    const double a12 = SQR (ring[p1]->x() - ring[p2]->x())+SQR (ring[p1]->y() - ring[p2]->y())+SQR (ring[p1]->z() - ring[p2]->z()); 
-    const double a13 = SQR (ring[p1]->x() - ring[p3]->x())+SQR (ring[p1]->y() - ring[p3]->y())+SQR (ring[p1]->z() - ring[p3]->z()); 
-    const double a23 = SQR (ring[p2]->x() - ring[p3]->x())+SQR (ring[p2]->y() - ring[p3]->y())+SQR (ring[p2]->z() - ring[p3]->z()); 
-    const double a123 = a12 + a13 + a23; 
-    const double v11 = SQR (ring[p1]->x() - v1->x())+SQR (ring[p1]->y() - v1->y())+SQR (ring[p1]->z() - v1->z()); 
-    const double v12 = SQR (ring[p2]->x() - v1->x())+SQR (ring[p2]->y() - v1->y())+SQR (ring[p2]->z() - v1->z()); 
-    const double v13 = SQR (ring[p3]->x() - v1->x())+SQR (ring[p3]->y() - v1->y())+SQR (ring[p3]->z() - v1->z()); 
-    const double v21 = SQR (ring[p1]->x() - v2->x())+SQR (ring[p1]->y() - v2->y())+SQR (ring[p1]->z() - v2->z()); 
-    const double v22 = SQR (ring[p2]->x() - v2->x())+SQR (ring[p2]->y() - v2->y())+SQR (ring[p2]->z() - v2->z()); 
-    const double v23 = SQR (ring[p3]->x() - v2->x())+SQR (ring[p3]->y() - v2->y())+SQR (ring[p3]->z() - v2->z()); 
+    const double a12 = SQR (ring[p1]->x() - ring[p2]->x())+SQR (ring[p1]->y() - ring[p2]->y())+SQR (ring[p1]->z() - ring[p2]->z());
+    const double a13 = SQR (ring[p1]->x() - ring[p3]->x())+SQR (ring[p1]->y() - ring[p3]->y())+SQR (ring[p1]->z() - ring[p3]->z());
+    const double a23 = SQR (ring[p2]->x() - ring[p3]->x())+SQR (ring[p2]->y() - ring[p3]->y())+SQR (ring[p2]->z() - ring[p3]->z());
+    const double a123 = a12 + a13 + a23;
+    const double v11 = SQR (ring[p1]->x() - v1->x())+SQR (ring[p1]->y() - v1->y())+SQR (ring[p1]->z() - v1->z());
+    const double v12 = SQR (ring[p2]->x() - v1->x())+SQR (ring[p2]->y() - v1->y())+SQR (ring[p2]->z() - v1->z());
+    const double v13 = SQR (ring[p3]->x() - v1->x())+SQR (ring[p3]->y() - v1->y())+SQR (ring[p3]->z() - v1->z());
+    const double v21 = SQR (ring[p1]->x() - v2->x())+SQR (ring[p1]->y() - v2->y())+SQR (ring[p1]->z() - v2->z());
+    const double v22 = SQR (ring[p2]->x() - v2->x())+SQR (ring[p2]->y() - v2->y())+SQR (ring[p2]->z() - v2->z());
+    const double v23 = SQR (ring[p3]->x() - v2->x())+SQR (ring[p3]->y() - v2->y())+SQR (ring[p3]->z() - v2->z());
     tetQuality1[i] = volume1 / (a123 + v11 + v12 + v13);
     tetQuality2[i] = volume2 / (a123 + v21 + v22 + v23);
   }
@@ -499,16 +496,16 @@ bool edgeSwap(Tet *tet, int iLocalEdge,  tetContainer &T, int myThread)
   }
 
   if (best <= tetQualityRef) return false;
-  
+
   unsigned int counter = 0;
   for (int j = 0; j < sp.nbr_triangles_2; j++){
     int iT = sp.trianguls[iBest][j];
     int p1 = sp.triangles[iT][0];
     int p2 = sp.triangles[iT][1];
     int p3 = sp.triangles[iT][2];
-    Vertex *pv1 = ring[p1];
-    Vertex *pv2 = ring[p2];
-    Vertex *pv3 = ring[p3];
+    Vert *pv1 = ring[p1];
+    Vert *pv2 = ring[p2];
+    Vert *pv3 = ring[p3];
 
     Tet *nt1,*nt2;
     if (counter < cavity.size()) nt1 = cavity[counter++];
@@ -524,19 +521,20 @@ bool edgeSwap(Tet *tet, int iLocalEdge,  tetContainer &T, int myThread)
   }
 
   for(unsigned int i = counter; i < cavity.size(); i++) cavity[i]->V[0] = NULL;
-  
+
   connContainer ctnr;
-  for(unsigned int i = 0; i < outside.size(); i++) 
+  for(unsigned int i = 0; i < outside.size(); i++)
     for (int j=0;j<4;j++)
-      computeAdjacencies (outside[i],j,ctnr);      
-  
+      computeAdjacencies (outside[i],j,ctnr);
+
   return true;
 }
 
-static void edgeSwapPass (tetContainer &T) {
-  
+/*
+static void edgeSwapPass (tetContainer &T)
+{
 }
-
+*/
 
 /*
   Fixing a non star shaped cavity (non delaunay triangulations)
@@ -545,9 +543,10 @@ static void edgeSwapPass (tetContainer &T) {
   Finite Elements in Analysis and Design 25 (1997) 297-317
 */
 
-static void starShapeness (Vertex *v, connContainer &bndK,
+static void starShapeness (Vert *v, connContainer &bndK,
 			   std::vector<unsigned int> &_negatives,
-			   double threshold){
+			   double threshold)
+{
   _negatives.clear();
   for (unsigned int i=0; i< bndK.size(); i++) {
     // no symbolic perturbation
@@ -561,8 +560,8 @@ static void starShapeness (Vertex *v, connContainer &bndK,
   }
 }
 
-static Tet* tetContainsV (Vertex *v, cavityContainer &cavity){
-
+static Tet* tetContainsV (Vert *v, cavityContainer &cavity)
+{
   for (unsigned int i=0; i< cavity.size(); i++) {
     unsigned int count = 0;
     for (unsigned int j=0;j<4;j++){
@@ -581,7 +580,8 @@ static Tet* tetContainsV (Vertex *v, cavityContainer &cavity){
   return NULL;
 }
 
-static void buildDelaunayBall (cavityContainer &cavity, connContainer &faceToTet){
+static void buildDelaunayBall (cavityContainer &cavity, connContainer &faceToTet)
+{
   faceToTet.clear();
   for (unsigned int i=0; i< cavity.size(); i++) {
     Tet *t = cavity[i];
@@ -599,16 +599,18 @@ static void buildDelaunayBall (cavityContainer &cavity, connContainer &faceToTet
   }
 }
 
+/*
 static bool updateCavity(Tet *containsV,
 			 cavityContainer &cavity,
-			 connContainer &bndK, 
-			 int myThread, int K){
+			 connContainer &bndK,
+			 int myThread, int K)
+{
   bndK.clear();
   cavityContainer cc;
   cc.push_back(containsV);
   std::stack<Tet*> _stack;
   _stack.push(containsV);
-  
+
   while (!_stack.empty()){
     Tet *t = _stack.top();
     _stack.pop();
@@ -632,12 +634,13 @@ static bool updateCavity(Tet *containsV,
   cavity = cc;
   return true;
 }
-
+*/
 
 static bool removeIsolatedTets(Tet *containsV,
 			       cavityContainer &cavity,
-			       connContainer &bndK, 
-			       int myThread, int K){
+			       connContainer &bndK,
+			       int myThread, int K)
+{
   cavityContainer cc;
   cc.push_back(containsV);
   std::stack<Tet*> _stack;
@@ -648,7 +651,7 @@ static bool removeIsolatedTets(Tet *containsV,
     _stack.pop();
     for (int i=0;i<4;i++){
       Tet *neigh = t->T[i];
-      if (neigh && 
+      if (neigh &&
 	  (std::find(cc.begin(),cc.end(),neigh) == cc.end()) &&
 	  (std::find(cavity.begin(),cavity.end(),neigh) != cavity.end())){
 	cc.push_back(neigh);
@@ -662,7 +665,8 @@ static bool removeIsolatedTets(Tet *containsV,
   return true;
 }
 
-static Tet *tetInsideCavityWithFAce (Face &f, cavityContainer &cavity){
+static Tet *tetInsideCavityWithFAce (Face &f, cavityContainer &cavity)
+{
   //  printf("size of cavity %ld\n",cavity.size());
   for (unsigned int i=0; i< cavity.size(); i++) {
     Tet *t = cavity[i];
@@ -670,20 +674,19 @@ static Tet *tetInsideCavityWithFAce (Face &f, cavityContainer &cavity){
       if (t->getFace(iFace) == f) {
 	return t;
       }
-    }  
+    }
   }
   return NULL;
 }
 
-
 static bool fixDelaunayCavity (double threshold,
-			       Vertex *v,
+			       Vert *v,
 			       cavityContainer &cavity,
 			       connContainer &bndK,
 			       int myThread, int K,
-			       std::vector<unsigned int> & _negatives){
-  
-  starShapeness (v, bndK, _negatives, threshold);  
+			       std::vector<unsigned int> & _negatives)
+{
+  starShapeness (v, bndK, _negatives, threshold);
 
   if (_negatives.empty())return false;
 
@@ -693,7 +696,7 @@ static bool fixDelaunayCavity (double threshold,
 
   Msg::Debug("Fixing cavity (%3ld,%3ld) : %ld negatives",
 	     cavity.size(),bndK.size(), _negatives.size());
-  
+
   Tet *containsV = tetContainsV (v,cavity);
 
   if (! containsV) return true;
@@ -712,17 +715,18 @@ static bool fixDelaunayCavity (double threshold,
     }
     removeIsolatedTets(containsV, cavity,bndK,myThread,K);
     buildDelaunayBall (cavity,bndK);
-    starShapeness (v, bndK, _negatives, threshold);  
+    starShapeness (v, bndK, _negatives, threshold);
   }
   return false;
 }
 
 static void delaunayCavity2 (Tet *t,
 			    Tet *prev,
-			    Vertex *v,
+			    Vert *v,
 			    cavityContainer &cavity,
 			    connContainer &bnd,
-			    int thread, int iPnt){
+			    int thread, int iPnt)
+{
   t->set(thread, iPnt); // Mark the triangle
   cavity.push_back(t);
   for (int iNeigh=0; iNeigh<4 ; iNeigh++){
@@ -742,7 +746,8 @@ static void delaunayCavity2 (Tet *t,
   }
 }
 
-Tet* walk (Tet *t, Vertex *v, int maxx, double &totSearch, int thread){
+Tet* walk (Tet *t, Vert *v, int maxx, double &totSearch, int thread)
+{
   while (1){
     totSearch++;
     if (t == NULL) {
@@ -775,8 +780,8 @@ Tet* walk (Tet *t, Vertex *v, int maxx, double &totSearch, int thread){
   Msg::Fatal("Jump-and-Walk Failed (No neighbor)");
 }
 
-
-void __print (const char *name, connContainer &conn, Vertex *v){
+void __print (const char *name, connContainer &conn, Vert *v)
+{
   FILE *f = fopen(name,"w");
   fprintf(f,"View \"\"{\n");
 
@@ -792,7 +797,7 @@ void __print (const char *name, connContainer &conn, Vertex *v){
   fclose(f);
 }
 
-void __print (const char *name, int thread, tetContainer &T, Vertex *v){
+void __print (const char *name, int thread, tetContainer &T, Vert *v){
   FILE *f = fopen(name,"w");
   fprintf(f,"View \"\"{\n");
   if (v)fprintf(f,"SP(%g,%g,%g){%d};\n",v->x(),v->y(),v->z(),v->getNum());
@@ -823,8 +828,9 @@ void __print (const char *name, int thread, tetContainer &T, Vertex *v){
   fclose(f);
 }
 
-void print (std::vector<Vertex*> &V, std::vector<Tet*> &T){
-  std::map<Vertex*,int> nums;
+void print (std::vector<Vert*> &V, std::vector<Tet*> &T)
+{
+  std::map<Vert*,int> nums;
   for (unsigned int i=0;i<V.size();i++){
     nums[V[i]] = i;
   }
@@ -835,8 +841,8 @@ void print (std::vector<Vertex*> &V, std::vector<Tet*> &T){
   }
 }
 
-
-void print (const char *name, std::vector<Vertex*> &T){
+void print (const char *name, std::vector<Vert*> &T)
+{
   FILE *f = fopen(name,"w");
   fprintf(f,"View \"\"{\n");
   for (unsigned int i=0;i<T.size()-1;i++){
@@ -852,7 +858,8 @@ void print (const char *name, std::vector<Vertex*> &T){
 xxx10000 ok if all bits on my right are 0
 */
 
-bool canWeProcessCavity (cavityContainer &cavity, unsigned int myThread, unsigned int iPt) {
+bool canWeProcessCavity (cavityContainer &cavity, unsigned int myThread, unsigned int iPt)
+{
   unsigned int cSize = cavity.size();
   for (unsigned int j=0; j<cSize; j++) {
     Tet *f = cavity[j];
@@ -866,9 +873,10 @@ bool canWeProcessCavity (cavityContainer &cavity, unsigned int myThread, unsigne
   return true;
 }
 
-bool checkLocalDelaunayness(Tet* t){
+bool checkLocalDelaunayness(Tet* t)
+{
   if (t->V[0]){
-    for (int i=0;i<4;i++){    
+    for (int i=0;i<4;i++){
       Tet *n = t->T[i];
       if (n && n->inSphere(t->getOppositeVertex(i),0))return false;
     }
@@ -876,7 +884,8 @@ bool checkLocalDelaunayness(Tet* t){
   return true;
 }
 
-int checkLocalDelaunayness(tetContainer &c, int thread, char *msg){
+int checkLocalDelaunayness(tetContainer &c, int thread, char *msg)
+{
   int nLoc = 0;
   for (unsigned int i=0; i<c.size(thread); i++) {
     if (!checkLocalDelaunayness(c(thread,i)))nLoc++;
@@ -885,7 +894,8 @@ int checkLocalDelaunayness(tetContainer &c, int thread, char *msg){
   return nLoc ;
 }
 
-static Tet* randomTet (int thread,  tetContainer &allocator ){
+static Tet* randomTet (int thread,  tetContainer &allocator)
+{
   unsigned int N = allocator.size(thread);
   //  printf("coucou random TET %d %d\n",thread,N);
   while(1) {
@@ -896,13 +906,14 @@ static Tet* randomTet (int thread,  tetContainer &allocator ){
 
 
 //#define _VERBOSE 1
-void delaunayTrgl (const unsigned int numThreads, 
-		   const unsigned int NPTS_AT_ONCE, 
-		   unsigned int Npts, 
-		   std::vector<Vertex*> assignTo[],
-		   tetContainer &allocator, 
-		   double threshold){
-#ifdef _VERBOSE
+void delaunayTrgl (const unsigned int numThreads,
+		   const unsigned int NPTS_AT_ONCE,
+		   unsigned int Npts,
+		   std::vector<Vert*> assignTo[],
+		   tetContainer &allocator,
+		   double threshold)
+{
+#if defined(_VERBOSE)
   double totSearchGlob=0;
   double totCavityGlob=0;
 #endif
@@ -920,10 +931,12 @@ void delaunayTrgl (const unsigned int numThreads,
     maxLocSizeK = std::max(maxLocSizeK, s);
   }
 
+#if defined(_OPENMP)
 #pragma omp parallel num_threads(numThreads)
+#endif
   {
 
-#ifdef _OPENMP
+#if defined(_OPENMP)
     int  myThread = omp_get_thread_num();
 #else
     int  myThread = 0;
@@ -938,20 +951,20 @@ void delaunayTrgl (const unsigned int numThreads,
     connContainer faceToTet;
     std::vector<Tet*> Choice(NPTS_AT_ONCE);
     for (unsigned int K=0;K<NPTS_AT_ONCE;K++)Choice[K] = randomTet (myThread, allocator);
-    
+
 
     invalidCavities [myThread] = 0;
     unsigned int locSize=0;
     std::vector<unsigned int> locSizeK(NPTS_AT_ONCE);
-    std::vector<Vertex*> allocatedVerts(NPTS_AT_ONCE);
+    std::vector<Vert*> allocatedVerts(NPTS_AT_ONCE);
     for (unsigned int K=0;K<NPTS_AT_ONCE;K++){
       locSizeK[K] = assignTo[K+myThread*NPTS_AT_ONCE].size();
       locSize += locSizeK[K];
-#ifdef _HAVE_NUMA
-      allocatedVerts [K] = (Vertex*)numa_alloc_local (locSizeK[K]*sizeof(Vertex));
+#if defined(_HAVE_NUMA)
+      allocatedVerts [K] = (Vert*)numa_alloc_local (locSizeK[K]*sizeof(Vert));
 #else
-      //      allocatedVerts [K] = (Vertex*)calloc (locSizeK[K],sizeof(Vertex));
-      allocatedVerts [K] = new Vertex [locSizeK[K]];
+      //      allocatedVerts [K] = (Vert*)calloc (locSizeK[K],sizeof(Vert));
+      allocatedVerts [K] = new Vert [locSizeK[K]];
 #endif
       for (unsigned int iP=0 ; iP < locSizeK[K] ; iP++){
 	allocatedVerts[K][iP] = *(assignTo[K+myThread*NPTS_AT_ONCE][iP]);
@@ -959,15 +972,20 @@ void delaunayTrgl (const unsigned int numThreads,
       }
     }
 
-    std::vector<Vertex*> vToAdd(NPTS_AT_ONCE);
+    std::vector<Vert*> vToAdd(NPTS_AT_ONCE);
 
+#if defined(_OPENMP)
 #pragma omp barrier
+#endif
+
     ////////////////////////////////////////////////////////////////////////////////////
     ////////////////////////// M A I N   L O O P ///////////////////////////////////////
     ////////////////////////////////////////////////////////////////////////////////////
 
     for (unsigned int iPGlob=0 ; iPGlob < maxLocSizeK; iPGlob++){
+#if defined(_OPENMP)
 #pragma omp barrier
+#endif
       std::vector<Tet*> t(NPTS_AT_ONCE);
       //	  double c1 = Cpu();
       // FIND SEEDS
@@ -1008,8 +1026,9 @@ void delaunayTrgl (const unsigned int numThreads,
 
       //      t3 += Cpu() - t1;
 
+#if defined(_OPENMP)
 #pragma omp barrier
-
+#endif
       for (unsigned int K=0; K< NPTS_AT_ONCE; K++) {
 	if (!vToAdd[K])ok[K]=false;
 	else ok[K] = canWeProcessCavity (cavity[K], myThread, K);
@@ -1051,14 +1070,18 @@ void delaunayTrgl (const unsigned int numThreads,
       }
       //      t4 += Cpu() - t1;
     }
-#ifdef _VERBOSE
+#if defined(_VERBOSE)
+#if defined(_OPENMP)
     #pragma omp critical
+#endif
     {
       totCavityGlob+= totCavity;
       totSearchGlob+= totSearch;
     }
 #endif
+#if defined(_OPENMP)
     #pragma omp barrier
+#endif
     // clear last cavity
     for (unsigned int K=0; K< NPTS_AT_ONCE; K++) {
       for (unsigned int i=0; i<cavity[K].size(); i++)cavity[K][i]->unset(myThread,K);
@@ -1073,7 +1096,7 @@ void delaunayTrgl (const unsigned int numThreads,
 
   //  printf(" %12.5E %12.5E  %12.5E tot  %12.5E \n",t2,t3,t4,t2+t3+t4);
 
-#ifdef _VERBOSE
+#if defined(_VERBOSE)
   printf("average searches per point  %12.5E\n",totSearchGlob/Npts);
   printf("average size for del cavity %12.5E\n",totCavityGlob/Npts);
   printf("cache misses: ");
@@ -1086,26 +1109,26 @@ void delaunayTrgl (const unsigned int numThreads,
 
 }
 
-
-static void initialCube (std::vector<Vertex*> &v,
-			 Vertex *box[8],
-			 tetContainer & allocator){
+static void initialCube (std::vector<Vert*> &v,
+			 Vert *box[8],
+			 tetContainer & allocator)
+{
   SBoundingBox3d bbox ;
   //  bbox += SPoint3(0,0,0);
   //  bbox += SPoint3(1,1,1);
   for (size_t i=0;i<v.size();i++){
-    Vertex *pv = v[i];
+    Vert *pv = v[i];
     bbox += SPoint3(pv->x(),pv->y(),pv->z());
   }
   bbox *= 1.3;
-  box[0] = new Vertex (bbox.min().x(),bbox.min().y(),bbox.min().z(),bbox.diag());
-  box[1] = new Vertex (bbox.max().x(),bbox.min().y(),bbox.min().z(),bbox.diag());
-  box[2] = new Vertex (bbox.max().x(),bbox.max().y(),bbox.min().z(),bbox.diag());
-  box[3] = new Vertex (bbox.min().x(),bbox.max().y(),bbox.min().z(),bbox.diag());
-  box[4] = new Vertex (bbox.min().x(),bbox.min().y(),bbox.max().z(),bbox.diag());
-  box[5] = new Vertex (bbox.max().x(),bbox.min().y(),bbox.max().z(),bbox.diag());
-  box[6] = new Vertex (bbox.max().x(),bbox.max().y(),bbox.max().z(),bbox.diag());
-  box[7] = new Vertex (bbox.min().x(),bbox.max().y(),bbox.max().z(),bbox.diag());
+  box[0] = new Vert (bbox.min().x(),bbox.min().y(),bbox.min().z(),bbox.diag());
+  box[1] = new Vert (bbox.max().x(),bbox.min().y(),bbox.min().z(),bbox.diag());
+  box[2] = new Vert (bbox.max().x(),bbox.max().y(),bbox.min().z(),bbox.diag());
+  box[3] = new Vert (bbox.min().x(),bbox.max().y(),bbox.min().z(),bbox.diag());
+  box[4] = new Vert (bbox.min().x(),bbox.min().y(),bbox.max().z(),bbox.diag());
+  box[5] = new Vert (bbox.max().x(),bbox.min().y(),bbox.max().z(),bbox.diag());
+  box[6] = new Vert (bbox.max().x(),bbox.max().y(),bbox.max().z(),bbox.diag());
+  box[7] = new Vert (bbox.min().x(),bbox.max().y(),bbox.max().z(),bbox.diag());
 
   /*  Tet *t0 = new Tet (box[2],box[7],box[3],box[1]);
   Tet *t1 = new Tet (box[0],box[7],box[1],box[3]);
@@ -1135,9 +1158,10 @@ static void initialCube (std::vector<Vertex*> &v,
 
 void delaunayTriangulation (const int numThreads,
 			    const int nptsatonce,
-			    std::vector<Vertex*> &S,
-			    Vertex *box[8],
-			    tetContainer & allocator){
+			    std::vector<Vert*> &S,
+			    Vert *box[8],
+			    tetContainer & allocator)
+{
   int N = S.size();
 
   std::vector<int> indices;
@@ -1150,8 +1174,8 @@ void delaunayTriangulation (const int numThreads,
   //  int blockSize = (nbBlocks * (N / nbBlocks))/nbBlocks;
 
 
-  std::vector<Vertex*> assignTo0[1];
-  std::vector<std::vector<Vertex*> > assignTo(nbBlocks);
+  std::vector<Vert*> assignTo0[1];
+  std::vector<std::vector<Vert*> > assignTo(nbBlocks);
 
   for (unsigned int i=1;i<indices.size();i++){
     int start = indices[i-1];
@@ -1188,9 +1212,10 @@ void delaunayTriangulation (const int numThreads,
 void delaunayTriangulation (const int numThreads,
 			    const int nptsatonce,
 			    std::vector<MVertex*> &S,
-			    std::vector<MTetrahedron*> &T){
+			    std::vector<MTetrahedron*> &T)
+{
   std::vector<MVertex*> _temp;
-  std::vector<Vertex*> _vertices;
+  std::vector<Vert*> _vertices;
   unsigned int N = S.size();
   _temp.resize(N+1+8);
   double maxx=0, maxy=0,maxz=0;
@@ -1213,8 +1238,8 @@ void delaunayTriangulation (const int numThreads,
     mv->x() += dx;
     mv->y() += dy;
     mv->z() += dz;
-    //    Vertex *v = new Vertex (mv->x(),mv->y(),mv->z(),1.e22,i+1);
-    Vertex *v = new Vertex (mv->x(),mv->y(),mv->z(),1.e22,i+1);
+    //    Vert *v = new Vert (mv->x(),mv->y(),mv->z(),1.e22,i+1);
+    Vert *v = new Vert (mv->x(),mv->y(),mv->z(),1.e22,i+1);
     _vertices.push_back(v);
     _temp [v->getNum()] = mv;
   }
@@ -1223,16 +1248,17 @@ void delaunayTriangulation (const int numThreads,
 
   // FIXME numThreads
 
-  Vertex *box[8];
+  Vert *box[8];
   delaunayTriangulation (numThreads, nptsatonce, _vertices, box, allocator);
+  //__print ("finalTetrahedrization.pos",0, allocator);
 
+  MVertex *VV[8];
   for (int i=0;i<8;i++){
-    Vertex *v = box[i];
+    Vert *v = box[i];
     v->setNum(N+i+1);
-    MVertex *mv = new MVertex (v->x(),v->y(),v->z(),NULL,N+i+1);
-    //    printf("%d %g %g %g\n",v->getNum(),v->x(),v->y(),v->z());
-    _temp [v->getNum()] = mv;
-    S.push_back(mv);
+    VV[i]= new MVertex (v->x(),v->y(),v->z(),NULL,N+(i+1));
+    _temp [v->getNum()] = VV[i];
+    S.push_back(VV[i]);
   }
 
   for (int myThread=0; myThread < numThreads; myThread++) {
