@@ -78,34 +78,36 @@ static double smoothPrimitive(GEdge *ge, double alpha,
 
 static double F_LcB(GEdge *ge, double t)
 {
-  BoundaryLayerField *blf = 0;
+  /*  BoundaryLayerField *blf = 0;
 #if defined(HAVE_ANN)
   FieldManager *fields = ge->model()->getFields();
   Field *bl_field = fields->get(fields->getBoundaryLayerField());
   blf = dynamic_cast<BoundaryLayerField*> (bl_field);
 #endif
-
+  */
   GPoint p = ge->point(t);
   double lc = BGM_MeshSize(ge, t, 0, p.x(), p.y(), p.z());
 
-  if (blf){
+  /*  if (blf){
     double lc2 = (*blf)( p.x(), p.y(), p.z() , ge);
     //    printf("p %g %g lc %g\n",p.x(),p.y(),lc2);
     lc = std::min(lc, lc2);
   }
+  */
 
   return lc;
 }
 
 static double F_Lc(GEdge *ge, double t)
 {
+  /*
   BoundaryLayerField *blf = 0;
 #if defined(HAVE_ANN)
   FieldManager *fields = ge->model()->getFields();
   Field *bl_field = fields->get(fields->getBoundaryLayerField());
   blf = dynamic_cast<BoundaryLayerField*> (bl_field);
 #endif
-
+  */
   GPoint p = ge->point(t);
   double lc_here;
 
@@ -119,13 +121,13 @@ static double F_Lc(GEdge *ge, double t)
     lc_here = BGM_MeshSize(ge->getEndVertex(), t, 0, p.x(), p.y(), p.z());
   else
     lc_here = BGM_MeshSize(ge, t, 0, p.x(), p.y(), p.z());
-
+  /*
   if (blf){
     double lc2 = (*blf)( p.x(), p.y(), p.z() , ge);
     //    printf("p %g %g lc %g\n",p.x(),p.y(),lc2);
     lc_here = std::min(lc_here, lc2);
   }
-
+  */
   SVector3 der = ge->firstDer(t);
   const double d = norm(der);
 
@@ -379,10 +381,10 @@ static int increaseN (int N)
 
 // ensure not to have points that are too close to each other.
 // can be caused by a coarse 1D mesh or by a noisy curve
-static void filterPoints (GEdge*ge, int nMinimumPoints)
+static void filterPoints(GEdge*ge, int nMinimumPoints)
 {
-  if (ge->mesh_vertices.empty())return;
-  if(ge->meshAttributes.method == MESH_TRANSFINITE)return;
+  if(ge->mesh_vertices.empty()) return;
+  if(ge->meshAttributes.method == MESH_TRANSFINITE) return;
   //if (ge->mesh_vertices.size() <=3)return;
   bool forceOdd = false;
   if((ge->meshAttributes.method != MESH_TRANSFINITE ||
@@ -445,7 +447,28 @@ static void filterPoints (GEdge*ge, int nMinimumPoints)
   }
 }
 
-void meshGEdge::operator() (GEdge *ge)
+static void createPoints ( GVertex *gv, GEdge *ge, BoundaryLayerField *blf ,
+			   std::vector<MVertex*>& v, const SVector3 &dir){
+  double L = blf->hwall_n;
+
+  double LEdge = distance (ge->getBeginVertex()->mesh_vertices[0],
+			   ge->getEndVertex()->mesh_vertices[0]);
+
+  while (1){
+    if (L > blf->thickness || L > LEdge * .4) break;
+    SPoint3 p (gv->x() + dir.x() * L, gv->y() + dir.y() * L, 0.0);
+    v.push_back(new MEdgeVertex (p.x(), p.y(), p.z(), ge,  ge->parFromPoint(p), blf->hfar));
+    int ith = v.size() ;
+    L+= blf->hwall_n * pow (blf->ratio, ith);
+    //    printf("parameter %g length %g\n",ge->parFromPoint(p),L);
+  }
+}
+
+void addBoundaryLayerPoints (GEdge *ge,
+			     double &t_begin, // may change the left  parameter of the interval
+			     double &t_end,   // may change the right parameter of the interval
+			     std::vector<MVertex*> &_addBegin, // additional points @ left
+			     std::vector<MVertex*> &_addEnd)   // additional points @ right
 {
   BoundaryLayerField *blf = 0;
 #if defined(HAVE_ANN)
@@ -454,6 +477,45 @@ void meshGEdge::operator() (GEdge *ge)
   blf = dynamic_cast<BoundaryLayerField*> (bl_field);
   if (blf) blf->setupFor1d(ge->tag());
 #endif
+  if (!blf) return;
+  if (blf->isEdgeBL(ge->tag()))return;
+  SVector3 dir ( ge->getEndVertex()->x() - ge->getBeginVertex()->x(),
+		 ge->getEndVertex()->y() - ge->getBeginVertex()->y(),
+		 ge->getEndVertex()->z() - ge->getBeginVertex()->z());
+  dir.normalize();
+  GVertex *gvb = ge->getBeginVertex();
+  GVertex *gve = ge->getEndVertex();
+  if (blf->isEndNode(gvb->tag())){
+    if (ge->geomType() != GEntity::Line){
+      Msg::Error ("Boundary layer end point %d should lie on a straight line", gvb->tag());
+      return;
+    }
+    createPoints (gvb, ge, blf, _addBegin, dir);
+    if (!_addBegin.empty())_addBegin[_addBegin.size()-1]->getParameter(0,t_begin);
+  }
+  if (blf->isEndNode(gve->tag())){
+    if (ge->geomType() != GEntity::Line){
+      Msg::Error ("Boundary layer end point %d should lie on a straight line", gve->tag());
+      return;
+    }
+    createPoints (gve, ge, blf, _addEnd, dir * -1.0);
+    if (!_addEnd.empty())_addEnd[_addEnd.size()-1]->getParameter(0,t_end);
+  }
+
+  //  printf("Edge %d § %d %d points added (%g %g)-\n", ge->tag(), _addBegin.size(),_addEnd.size(),t_begin,t_end);
+}
+
+void meshGEdge::operator() (GEdge *ge)
+{
+  /*
+  BoundaryLayerField *blf = 0;
+#if defined(HAVE_ANN)
+  FieldManager *fields = ge->model()->getFields();
+  Field *bl_field = fields->get(fields->getBoundaryLayerField());
+  blf = dynamic_cast<BoundaryLayerField*> (bl_field);
+  if (blf) blf->setupFor1d(ge->tag());
+#endif
+  */
 
   ge->model()->setCurrentMeshEntity(ge);
 
@@ -488,6 +550,10 @@ void meshGEdge::operator() (GEdge *ge)
   double t_begin = bounds.low();
   double t_end = bounds.high();
 
+  // if a BL is ending at one of the ends, then create specific points
+  std::vector<MVertex*> _addBegin, _addEnd;
+  addBoundaryLayerPoints (ge, t_begin, t_end, _addBegin, _addEnd);
+
   // first compute the length of the curve by integrating one
   double length;
   std::vector<IntPoint> Points;
@@ -541,7 +607,7 @@ void meshGEdge::operator() (GEdge *ge)
       SVector3 der = ge->firstDer(pt.t);
       pt.xp = der.norm();
     }
-    //    a = smoothPrimitive(ge, sqrt(CTX::instance()->mesh.smoothRatio), Points);
+    a = smoothPrimitive(ge, sqrt(CTX::instance()->mesh.smoothRatio), Points);
     filterMinimumN = ge->minimumMeshSegments() + 1;
     N = std::max(filterMinimumN, (int)(a + 1.99));
   }
@@ -609,7 +675,7 @@ void meshGEdge::operator() (GEdge *ge)
         const double d = norm(der);
         double lc  = d/(P1.lc + dlc / dp * (d - P1.p));
         GPoint V = ge->point(t);
-	//	printf("%d %g\n",NUMP-1,t);
+	// printf("%d %g\n",NUMP-1,t);
         mesh_vertices[NUMP - 1] = new MEdgeVertex(V.x(), V.y(), V.z(), ge, t, lc);
         NUMP++;
       }
@@ -620,8 +686,20 @@ void meshGEdge::operator() (GEdge *ge)
     mesh_vertices.resize(NUMP - 1);
   }
 
+  // Boundary Layer points are added
+  {
+    std::vector<MVertex*> vv;
+    vv.insert(vv.end(), _addBegin.begin(), _addBegin.end());
+    vv.insert(vv.end(), mesh_vertices.begin(), mesh_vertices.end());
+    for (unsigned int i=0;i<_addEnd.size();i++)
+      vv.push_back(_addEnd[_addEnd.size()-1-i]);
+    //    vv.insert(vv.end(), _addEnd.rend(), _addEnd.rbegin());
+    mesh_vertices = vv;
+  }
+
   //  printf("%ld ----> ", ge->mesh_vertices.size());
-  filterPoints (ge, filterMinimumN - 2);
+  if (_addBegin.empty() && _addEnd.empty())
+    filterPoints (ge, filterMinimumN - 2);
   //  printf("%ld \n", ge->mesh_vertices.size());
 
   for(unsigned int i = 0; i < mesh_vertices.size() + 1; i++){
