@@ -662,8 +662,12 @@ static void modifyInitialMeshForTakingIntoAccountBoundaryLayers(GFace *gf)
   FILE *ff2 = Fopen ("tato.pos","w");
   if(ff2) fprintf(ff2,"View \" \"{\n");
   std::set<MVertex*> verts;
+
+  std::vector<MLine*> _lines;
+
   while(ite != edges.end()){
     for(unsigned int i = 0; i< (*ite)->lines.size(); i++){
+      _lines.push_back((*ite)->lines[i]);
       MVertex *v1 = (*ite)->lines[i]->getVertex(0);
       MVertex *v2 = (*ite)->lines[i]->getVertex(1);
       MEdge dv(v1,v2);
@@ -686,19 +690,16 @@ static void modifyInitialMeshForTakingIntoAccountBoundaryLayers(GFace *gf)
             v11 = c1._column[l-1];
             v12 = c2._column[l-1];
           }
-          MEdge dv2 (v21,v22);
-
-          //avoid convergent errors
-          if (dv2.length() < 0.03 * dv.length())break;
           MQuadrangle *qq = new MQuadrangle(v11,v21,v22,v12);
+	  qq->setPartition (l+1);
           myCol.push_back(qq);
           blQuads.push_back(qq);
           if(ff2)
-            fprintf(ff2,"SQ (%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g){1,1,1,1};\n",
+            fprintf(ff2,"SQ (%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g){%d,%d,%d,%d};\n",
                     v11->x(),v11->y(),v11->z(),
                     v12->x(),v12->y(),v12->z(),
                     v22->x(),v22->y(),v22->z(),
-                    v21->x(),v21->y(),v21->z());
+                    v21->x(),v21->y(),v21->z(),l+1,l+1,l+1,l+1);
         }
         // int M = std::max(c1._column.size(),c2._column.size());
         for (unsigned int l=0;l<myCol.size();l++)_columns->_toFirst[myCol[l]] = myCol[0];
@@ -713,11 +714,12 @@ static void modifyInitialMeshForTakingIntoAccountBoundaryLayers(GFace *gf)
     MVertex *v = itf->first;
     int nbCol = _columns->getNbColumns(v);
 
-    std::vector<MElement*> myCol;
     for (int i=0;i<nbCol-1;i++){
       const BoundaryLayerData & c1 = _columns->getColumn(v,i);
       const BoundaryLayerData & c2 = _columns->getColumn(v,i+1);
       int N = std::min(c1._column.size(),c2._column.size());
+      //      printf("%d %d\n",c1._column.size(),c2._column.size());
+      std::vector<MElement*> myCol;
       for (int l=0;l < N ;++l){
         MVertex *v11,*v12,*v21,*v22;
         v21 = c1._column[l];
@@ -732,29 +734,31 @@ static void modifyInitialMeshForTakingIntoAccountBoundaryLayers(GFace *gf)
         }
         if (v11 != v12){
           MQuadrangle *qq = new MQuadrangle(v11,v12,v22,v21);
+	  qq->setPartition (l+1);
           myCol.push_back(qq);
           blQuads.push_back(qq);
           if(ff2)
-            fprintf(ff2,"SQ (%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g){1,1,1,1};\n",
+            fprintf(ff2,"SQ (%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g){%d,%d,%d,%d};\n",
                     v11->x(),v11->y(),v11->z(),
                     v12->x(),v12->y(),v12->z(),
                     v22->x(),v22->y(),v22->z(),
-                    v21->x(),v21->y(),v21->z());
+                    v21->x(),v21->y(),v21->z(),l+1,l+1,l+1,l+1);
         }
         else {
           MTriangle *qq = new MTriangle(v,v22,v21);
+	  qq->setPartition (l+1);
           myCol.push_back(qq);
           blTris.push_back(qq);
           if(ff2)
-            fprintf(ff2,"ST (%g,%g,%g,%g,%g,%g,%g,%g,%g){1,1,1,1};\n",
+            fprintf(ff2,"ST (%g,%g,%g,%g,%g,%g,%g,%g,%g){%d,%d,%d};\n",
                     v->x(),v->y(),v->z(),
                     v22->x(),v22->y(),v22->z(),
-                    v21->x(),v21->y(),v21->z());
+                    v21->x(),v21->y(),v21->z(),l+1,l+1,l+1);
         }
       }
+      for (unsigned int l=0;l<myCol.size();l++)_columns->_toFirst[myCol[l]] = myCol[0];
+      _columns->_elemColumns[myCol[0]] = myCol;
     }
-    for (unsigned int l=0;l<myCol.size();l++)_columns->_toFirst[myCol[l]] = myCol[0];
-    _columns->_elemColumns[myCol[0]] = myCol;
   }
 
   if(ff2){
@@ -762,7 +766,7 @@ static void modifyInitialMeshForTakingIntoAccountBoundaryLayers(GFace *gf)
     fclose(ff2);
   }
 
-  //  filterOverlappingElements (blTris,blQuads,_columns->_elemColumns,_columns->_toFirst);
+  filterOverlappingElements (_lines, blTris,blQuads,_columns->_elemColumns,_columns->_toFirst);
 
   for (unsigned int i = 0; i < blQuads.size();i++){
     addOrRemove(blQuads[i]->getVertex(0),blQuads[i]->getVertex(1),bedges, removed);
@@ -1543,8 +1547,9 @@ bool meshGenerator(GFace *gf, int RECUR_ITER,
   // BDS mesh is passed in order not to recompute local coordinates of
   // vertices
   if(algoDelaunay2D(gf) && !onlyInitialMesh){
-    if(gf->getMeshingAlgo() == ALGO_2D_FRONTAL)
+    if(gf->getMeshingAlgo() == ALGO_2D_FRONTAL){
       bowyerWatsonFrontal(gf);
+    }
     else if(gf->getMeshingAlgo() == ALGO_2D_FRONTAL_QUAD){
       bowyerWatsonFrontalLayers(gf,true);
     }
@@ -2592,8 +2597,8 @@ void partitionAndRemesh(GFaceCompound *gf)
   Msg::Info("*** Starting meshing 1D edges ...:");
   for (int i = 0; i < NE; i++){
     GEdge *gec = gf->model()->getEdgeByTag(nume + NE + i);
-     meshGEdge mge;
-     mge(gec);
+    meshGEdge mge;
+    mge(gec);
   }
   double t2 = Cpu();
   Msg::Info("*** Meshing 1D edges done (%gs)", t2-t1);
