@@ -704,6 +704,7 @@ bool insertVertexB (std::list<edgeXface> &shell,
 		    double *metric,
 		    MTri3 **oneNewTriangle)
 {
+  if (cavity.size() == 1) return false;
   if (shell.size() != cavity.size() + 2) return false;
 
   std::list<MTri3*> new_cavity;
@@ -747,7 +748,7 @@ bool insertVertexB (std::list<edgeXface> &shell,
     // avoid angles that are too obtuse
     double cosv = ((d1*d1+d2*d2-d3*d3)/(2.*d1*d2));
 
-    if ((d1 < LL * .25 || d2 < LL * .25 || cosv < -.9999) && !force) {
+    if ((d1 < LL * .55 || d2 < LL * .55 || cosv < -.9999) && !force) {
       onePointIsTooClose = true;
       //      printf("%12.5E %12.5E %12.5E %12.5E \n",d1,d2,LL,cosv);
     }
@@ -827,7 +828,7 @@ bool insertVertex(bool force, GFace *gf, MVertex *v, double *param , MTri3 *t,
   else{
     recurFindCavityAniso(gf, shell, cavity, metric, param, t, data);
   }
-
+  
   return insertVertexB(shell, cavity, force, gf, v, param , t,
 		       allTets,
 		       activeTets,
@@ -1058,7 +1059,7 @@ void bowyerWatson(GFace *gf, int MAXPNT,
   //  if (equivalence)_printTris ("before.pos", AllTris.begin(), AllTris.end(), DATA);
   int nbSwaps = edgeSwapPass(gf, AllTris, SWCR_DEL, DATA);
   // _printTris ("after2.pos", AllTris, Us,Vs);
-  Msg::Debug("Delaunization of the initial mesh done (%d swaps)", nbSwaps);
+  //  Msg::Debug("Delaunization of the initial mesh done (%d swaps)", nbSwaps);
 
   if(AllTris.empty()){
     Msg::Error("No triangles in initial mesh");
@@ -1115,7 +1116,7 @@ void bowyerWatson(GFace *gf, int MAXPNT,
   //  printf("%12.5E %12.5E %12.5E %12.5E %12.5E\n",DT1,DT2,DT3,__DT1,__DT2);
   //  printf("%12.5E \n",__DT2);
 #if defined(HAVE_ANN)
-  {
+  if (!CTX::instance()->mesh.recombineAll && !gf->meshAttributes.recombine){
     FieldManager *fields = gf->model()->getFields();
     BoundaryLayerField *blf = 0;
     if(fields->getBoundaryLayerField() > 0){
@@ -1290,21 +1291,17 @@ bool optimalPointFrontalB (GFace *gf,
 {
   // as a starting point, let us use the "fast algo"
   double d = optimalPointFrontal (gf,worst,active_edge,data,newPoint,metric);
-  int ip1 = active_edge - 1 < 0 ? 2 : active_edge - 1;
+  int ip1 = (active_edge+2)%3;
   int ip2 = active_edge;
+  int ip3 = (active_edge+1)%3;
   MVertex *v1 = worst->tri()->getVertex(ip1);
   MVertex *v2 = worst->tri()->getVertex(ip2);
-  MTriangle *t = worst->tri();
-  double p1[3] = {t->getVertex(0)->x(), t->getVertex(0)->y(), t->getVertex(0)->z()};
-  double p2[3] = {t->getVertex(1)->x(), t->getVertex(1)->y(), t->getVertex(1)->z()};
-  double p3[3] = {t->getVertex(2)->x(), t->getVertex(2)->y(), t->getVertex(2)->z()};
-  double c[3];
-  circumCenterXYZ(p1, p2, p3, c);
+  MVertex *v3 = worst->tri()->getVertex(ip3);
   SVector3 middle ((v1->x()+v2->x())*.5,(v1->y()+v2->y())*.5,(v1->z()+v2->z())*.5);
-  SVector3 center(c[0],c[1],c[2]);
   SVector3 v1v2 (v2->x()-v1->x(),v2->y()-v1->y(),v2->z()-v1->z());
-  SVector3 n1 = center - middle;
-  SVector3 n2 = crossprod(v1v2,n1);
+  SVector3 tmp (v3->x()-middle.x(),v3->y()-middle.y(),v3->z()-middle.z());
+  SVector3 n1 = crossprod(v1v2,tmp);
+  SVector3 n2 = crossprod(n1,v1v2);
   n1.normalize();
   n2.normalize();
   // we look for a point that is
@@ -1330,7 +1327,7 @@ bool optimalPointFrontalB (GFace *gf,
   if (gf->geomType() == GEntity::CompoundSurface){
     GFaceCompound *gfc = dynamic_cast<GFaceCompound*> (gf);
     if (gfc){
-      GPoint gp = gfc->intersectionWithCircle(n1,n2,middle,d,newPoint);
+      GPoint gp = gfc->intersectionWithCircle(n2,n1,middle,d,newPoint);
       if (gp.succeeded()){
 	newPoint[0] = gp.u();
 	newPoint[1] = gp.v();
@@ -1340,7 +1337,7 @@ bool optimalPointFrontalB (GFace *gf,
   }
 
   double uvt[3] = {newPoint[0],newPoint[1],0.0};
-  curveFunctorCircle cc (n1,n2,middle,d);
+  curveFunctorCircle cc (n2,n1,middle,d);
   surfaceFunctorGFace ss (gf);
 
   if (intersectCurveSurface (cc,ss,uvt,d*1.e-8)){
@@ -1350,6 +1347,7 @@ bool optimalPointFrontalB (GFace *gf,
   else {
     Msg::Debug("--- Non optimal point found -----------");
     return false;
+    return true;
     //    Msg::Info("--- Non optimal point found -----------");
   }
   return true;
@@ -1435,7 +1433,7 @@ void bowyerWatsonFrontal(GFace *gf,
 
   // in case of boundary layer meshing
 #if defined(HAVE_ANN)
-  {
+  if (!CTX::instance()->mesh.recombineAll && !gf->meshAttributes.recombine){
     FieldManager *fields = gf->model()->getFields();
     BoundaryLayerField *blf = 0;
     if(fields->getBoundaryLayerField() > 0){
@@ -1724,26 +1722,26 @@ void bowyerWatsonFrontalLayers(GFace *gf, bool quad,
 
     backgroundMesh::unset();
 #if defined(HAVE_ANN)
-    {
-      FieldManager *fields = gf->model()->getFields();
-      BoundaryLayerField *blf = 0;
-      if(fields->getBoundaryLayerField() > 0){
-        Field *bl_field = fields->get(fields->getBoundaryLayerField());
-        blf = dynamic_cast<BoundaryLayerField*> (bl_field);
-        if (blf && !blf->iRecombine)quadsToTriangles(gf,10000);
-      }
+  if (!CTX::instance()->mesh.recombineAll && !gf->meshAttributes.recombine){
+    FieldManager *fields = gf->model()->getFields();
+    BoundaryLayerField *blf = 0;
+    if(fields->getBoundaryLayerField() > 0){
+      Field *bl_field = fields->get(fields->getBoundaryLayerField());
+      blf = dynamic_cast<BoundaryLayerField*> (bl_field);
+      if (blf && !blf->iRecombine)quadsToTriangles(gf,10000);
     }
-#endif
   }
+#endif
+}
 
-  void bowyerWatsonParallelograms(GFace *gf,
-      std::map<MVertex* , MVertex*>* equivalence,
-      std::map<MVertex*, SPoint2> * parametricCoordinates)
-  {
-    std::set<MTri3*,compareTri3Ptr> AllTris;
-    bidimMeshData DATA(equivalence, parametricCoordinates);
-    std::vector<MVertex*> packed;
-    std::vector<SMetric3> metrics;
+void bowyerWatsonParallelograms(GFace *gf,
+				std::map<MVertex* , MVertex*>* equivalence,
+				std::map<MVertex*, SPoint2> * parametricCoordinates)
+{
+  std::set<MTri3*,compareTri3Ptr> AllTris;
+  bidimMeshData DATA(equivalence, parametricCoordinates);
+  std::vector<MVertex*> packed;
+  std::vector<SMetric3> metrics;
 
     //  printf("creating the points\n");
     // PEB MODIF
@@ -1818,7 +1816,7 @@ void bowyerWatsonFrontalLayers(GFace *gf, bool quad,
     transferDataStructure(gf, AllTris, DATA);
     backgroundMesh::unset();
 #if defined(HAVE_ANN)
-    {
+  if (!CTX::instance()->mesh.recombineAll && !gf->meshAttributes.recombine){
       FieldManager *fields = gf->model()->getFields();
       BoundaryLayerField *blf = 0;
       if(fields->getBoundaryLayerField() > 0){
@@ -1924,7 +1922,7 @@ void bowyerWatsonParallelogramsConstrained(GFace *gf,
   }
   backgroundMesh::unset();
 #if defined(HAVE_ANN)
-  {
+  if (!CTX::instance()->mesh.recombineAll && !gf->meshAttributes.recombine){
     FieldManager *fields = gf->model()->getFields();
     BoundaryLayerField *blf = 0;
     if(fields->getBoundaryLayerField() > 0){
