@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2015 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2016 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@geuz.org>.
+// bugs and problems to the public mailing list <gmsh@onelab.info>.
 
 #ifndef _MESH_GFACE_DELAUNAY_INSERTIONFACE_H_
 #define _MESH_GFACE_DELAUNAY_INSERTIONFACE_H_
@@ -157,6 +157,10 @@ void bowyerWatsonFrontalLayers(GFace *gf, bool quad,
 void bowyerWatsonParallelograms(GFace *gf,
 		  std::map<MVertex* , MVertex*>* equivalence= 0,
 		  std::map<MVertex*, SPoint2> * parametricCoordinates= 0);
+void bowyerWatsonParallelogramsConstrained(GFace *gf,
+		  std::set<MVertex*> constr_vertices,
+		  std::map<MVertex* , MVertex*>* equivalence= 0,
+		  std::map<MVertex*, SPoint2> * parametricCoordinates= 0);
 void buildBackGroundMesh (GFace *gf,
 		  std::map<MVertex* , MVertex*>* equivalence= 0,
 		  std::map<MVertex*, SPoint2> * parametricCoordinates= 0);
@@ -197,5 +201,4 @@ struct edgeXface
   }
 };
 
-
 #endif
