@@ -993,6 +993,40 @@ bool edgeSwap(std::set<swapquad> &configs, MTri3 *t1, GFace *gf, int iLocalEdge,
 }
 
 int edgeSwapPass(GFace *gf, std::set<MTri3*, compareTri3Ptr> &allTris,
+		 const swapCriterion &cr,bidimMeshData & data)
+{
+  typedef std::set<MTri3*, compareTri3Ptr> CONTAINER;
+  
+  int nbSwapTot = 0;
+  std::set<swapquad> configs;
+  for(int iter = 0; iter < 1200; iter++){
+    int nbSwap = 0;
+    std::vector<MTri3*> newTris;
+    for(CONTAINER::iterator it = allTris.begin(); it != allTris.end(); ++it){
+      if(!(*it)->isDeleted()){
+	for(int i = 0; i < 3; i++){
+	  if(edgeSwap(configs, *it, gf, i, newTris, cr, data)){
+	    nbSwap++;
+	    break;
+	  }
+	}
+      }
+      else{
+	delete *it;
+	CONTAINER::iterator itb = it;
+	++it;
+	allTris.erase(itb);
+	if(it == allTris.end()) break;
+      }
+    }
+    allTris.insert(newTris.begin(), newTris.end());
+    nbSwapTot += nbSwap;
+    if(nbSwap == 0) break;
+  }
+  return nbSwapTot;
+}
+
+int edgeSwapPass2(GFace *gf, std::set<MTri3*, compareTri3Ptr> &allTris,
                  const swapCriterion &cr,bidimMeshData & data)
 {
   typedef std::set<MTri3*, compareTri3Ptr> CONTAINER;
