@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2015 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2016 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@geuz.org>.
+// bugs and problems to the public mailing list <gmsh@onelab.info>.
 
 #ifndef _MESH_GFACE_OPTIMIZE_H_
 #define _MESH_GFACE_OPTIMIZE_H_
@@ -62,17 +62,12 @@ void laplaceSmoothing(GFace *gf, int niter=1, bool infinity_norm = false);
 void _relocateVertex(GFace *gf, MVertex *ver,
                      const std::vector<MElement*> &lt);
 
-/*
-void edgeSwappingLawson(GFace *gf);
-*/
-
 enum swapCriterion {SWCR_DEL, SWCR_QUAL, SWCR_NORM, SWCR_CLOSE};
 enum splitCriterion {SPCR_CLOSE, SPCR_QUAL, SPCR_ALLWAYS};
 
 int edgeSwapPass(GFace *gf,
                  std::set<MTri3*, compareTri3Ptr> &allTris,
                  const swapCriterion &cr, bidimMeshData &DATA);
-void removeFourTrianglesNodes(GFace *gf, bool replace_by_quads);
 void removeThreeTrianglesNodes(GFace *gf);
 void buildMeshGenerationDataStructures(GFace *gf,
                                        std::set<MTri3*, compareTri3Ptr> &AllTris,
@@ -82,11 +77,10 @@ void computeEquivalences(GFace *gf,bidimMeshData &DATA);
 void recombineIntoQuads(GFace *gf,
                         bool topologicalOpti   = true,
                         bool nodeRepositioning = true,
-			double minqual = 0.1);
+			double minqual = 0.1,
+			bool verbose = true);
 
 //used for meshGFaceRecombine development
-int recombineWithBlossom(GFace *gf, double dx, double dy,
-                         int *&, std::map<MElement*,int> &);
 void quadsToTriangles(GFace *gf, double minqual);
 
 struct swapquad{
@@ -159,29 +153,5 @@ struct RecombineTriangle
   }
 };
 
-/***************************************************/
-/******************class Temporary******************/
-/***************************************************/
-
-class Temporary{
- private :
-  static double w1,w2,w3;
-  static std::vector<SVector3> gradients;
-  void read_data(std::string);
-  static SVector3 compute_normal(MElement*);
-  static SVector3 compute_other_vector(MElement*);
-  static SVector3 compute_gradient(MElement*);
- public :
-  Temporary();
-  ~Temporary();
-  void quadrilaterize(std::string,double,double,double);
-  static double compute_total_cost(double,double);
-  static void select_weights(double,double,double);
-  static double compute_alignment(const MEdge&,MElement*,MElement*);
-};
-
-/***************************************************/
-/***************************************************/
-/***************************************************/
 
 #endif
