@@ -1,13 +1,16 @@
-// Gmsh - Copyright (C) 1997-2015 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2016 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@geuz.org>.
+// bugs and problems to the public mailing list <gmsh@onelab.info>.
 
 #include "meshGRegionLocalMeshMod.h"
 #include "GEntity.h"
 #include "GRegion.h"
 #include "GmshMessage.h"
 #include "Numeric.h"
+#include "MHexahedron.h"
+#include "MPrism.h"
+#include "MPyramid.h"
 
 static int edges[6][2] =    {{0,1},{0,2},{0,3},{1,2},{1,3},{2,3}};
 static int efaces[6][2] =   {{0,2},{0,1},{1,2},{0,3},{2,3},{1,3}};
@@ -68,11 +71,6 @@ bool buildEdgeCavity(MTet4 *t, int iLocalEdge, MVertex **v1, MVertex **v2,
   while (1){
     MVertex *ov1 = t->tet()->getVertex(edges[5 - iLocalEdge][0]);
     MVertex *ov2 = t->tet()->getVertex(edges[5 - iLocalEdge][1]);
-    //    printf("edge %d %d tet %d %d %d %d\n",(*v1)->getNum(),(*v2)->getNum(),
-    //	   t->tet()->getVertex(0)->getNum(),
-    //	   t->tet()->getVertex(1)->getNum(),
-    //	   t->tet()->getVertex(2)->getNum(),
-    //	   t->tet()->getVertex(3)->getNum());
     int K = ov1 == lastinring ? 1 : 0;
     lastinring = ov1 == lastinring ? ov2 : ov1;
     // look in the 2 faces sharing this edge the one that has vertex
@@ -107,20 +105,16 @@ bool buildEdgeCavity(MTet4 *t, int iLocalEdge, MVertex **v1, MVertex **v2,
       return false;
     }
     // FIXME when hybrid mesh, this loops for ever
-    if (cavity.size() > 1000) return false;
+    if (cavity.size() > 1000) {
+      printf("cavity size gets laaaarge\n");
+      return false;
+    }
     //    printf("%d %d\n",ITER++, cavity.size());
   }
   computeNeighboringTetsOfACavity (cavity,outside);
   return true;
 }
 
-typedef struct {
-  int nbr_triangles ;           /* number of different triangles       */
-  int (*triangles)[3] ;         /* triangles array                     */
-  int nbr_trianguls ;           /* number of different triangulations  */
-  int nbr_triangles_2 ;         /* number of triangles / triangulation */
-  int (*trianguls)[5] ;         /* retriangulations array              */
-} SwapPattern ;
 
 void BuildSwapPattern3(SwapPattern *sc)
 {
@@ -480,78 +474,6 @@ void buildVertexCavity_recur(MTet4 *t, MVertex *v, std::vector<MTet4*> &cavity)
 // another one (of course, not the other one on the unswappable edge)
 // after that crap, the sliver is trashed
 
-bool sliverRemoval(std::vector<MTet4*> &newTets, MTet4 *t,
-                   const qmTetrahedron::Measures &cr)
-{
-  std::vector<MTet4*> cavity;
-  std::vector<MTet4*> outside;
-  std::vector<MVertex*> ring;
-  MVertex *v1, *v2;
-
-  bool isClosed[6];
-  int nbSwappable = 0;
-  int iSwappable = 0;
-  for (int i = 0; i < 6; i++){
-     isClosed[i] = buildEdgeCavity(t, i, &v1, &v2, cavity, outside, ring);
-     if (isClosed[i]){
-       nbSwappable++;
-       iSwappable = i;
-     }
-  }
-
-  if (nbSwappable == 0){
-    // all edges are on model edges or model faces, which means that
-    // nothing can be done
-    return false;
-  }
-  else if (nbSwappable == 1){
-    // classical case, the sliver has 5 edges on the boundary
-    // try to swap first
-    if (edgeSwap(newTets,t,iSwappable,qmTetrahedron::QMTET_ETA))return true;
-    // if it does not work, split, smooth and collapse
-    MVertex *v1 = t->tet()->getVertex(edges[iSwappable][0]);
-    MVertex *v2 = t->tet()->getVertex(edges[iSwappable][1]);
-    MVertex *newv = new MVertex (0.5 * (v1->x() + v2->x()),
-                                 0.5 * (v1->y() + v2->y()),
-                                 0.5 * (v1->z() + v2->z()), t->onWhat());
-    t->onWhat()->mesh_vertices.push_back(newv);
-
-    if (!edgeSplit(newTets, t, newv, iSwappable, qmTetrahedron::QMTET_ONE)) return false;
-    for (int i = 0; i < 4; i++){
-      if (newTets[newTets.size() - 1]->tet()->getVertex(i) == newv){
-        smoothVertex(newTets[newTets.size() - 1], i, cr);
-        smoothVertexOptimize(newTets[newTets.size() - 1], i, cr);
-      }
-    }
-
-    for (unsigned int i = 0; i < newTets.size(); i++){
-      MTet4 *new_t = newTets[i];
-      if (!(new_t->isDeleted())){
-        for (int j = 0; j < 6; j++){
-          MVertex *va = new_t->tet()->getVertex(edges[j][0]);
-          MVertex *vb = new_t->tet()->getVertex(edges[j][1]);
-          if (va == newv &&
-              (va != v1  && vb != v1 && va != v2  && vb != v2)){
-            collapseVertex(newTets,new_t,edges[j][0],edges[j][1],cr);
-          }
-          else if (vb == newv &&
-                   (va != v1  && vb != v1 && va != v2  && vb != v2)){
-            collapseVertex(newTets,new_t,edges[j][1],edges[j][0],cr);
-          }
-        }
-      }
-    }
-    return true;
-  }
-  else{
-    for (int i = 0; i < 4; i++){
-      smoothVertex(t, i, cr);
-      smoothVertexOptimize(t, i, cr);
-    }
-  }
-  return false;
-}
-
 bool collapseVertex(std::vector<MTet4 *> &newTets,
                         MTet4 *t,
                         int iVertex,
@@ -836,303 +758,3 @@ bool smoothVertexOptimize(MTet4 *t, int iVertex, const qmTetrahedron::Measures &
   }
 }
 
-// Edge split sets ...
-// Here, we only build a list of tets that are a subdivision
-// of the given
-//static int edges[6][2] =    {{0,1},{0,2},{0,3},{1,2},{1,3},{2,3}};
-
-// the resulting triangles are 012 and 230 in vector res
-// void splitPrism (std::vector<MTet4 *> &newTets,
-//               std::vector<MVertex *> &steinerPoints,
-//               MVertex* v1,
-//               MVertex* v2,
-//               MVertex* v3,
-//               MVertex* v4,
-//               MVertex* v5,
-//               MVertex* v6,
-//               const qualityMeasure4Tet &cr,
-//               MVertex *res[4],
-//               fs_cont &search,
-//               GFace *fakeFace){
-// }
-
-// void splitQuadFace (MVertex* newv1,
-//                  MVertex* newv2,
-//                  MVertex* v21,
-//                  MVertex* v11,
-//                  const qualityMeasure4Tet &cr,
-//                  MVertex *res[4],
-//                  fs_cont &search,
-//                  GFace *fakeFace){
-//   GFace* gfound = findInFaceSearchStructure (newv1,newv2,v11,search);
-//   if (gfound){
-//     res[0] = newv2;
-//     res[1] = newv1;
-//     res[2] = v11;
-//     res[3] = v21;
-//   }
-//   else{
-//     GFace* gfound = findInFaceSearchStructure (newv1,newv2,v21,search);
-//     if (gfound){
-//       res[0] = newv1;
-//       res[1] = newv2;
-//       res[2] = v21;
-//       res[3] = v11;
-//     }
-//     // choose the best configuration
-//     else{
-//       double q1 = std::min(qmTri(newv1,newv2,v11,cr),qmTet(newv2,v11,v21,cr));
-//       double q2 = std::min(qmTet(newv1,newv2,v21,cr),qmTet(newv1,v11,v21,cr));
-//       if (q1 > q2){
-//      res[0] = newv2;
-//      res[1] = newv1;
-//      res[2] = v11;
-//      res[3] = v21;
-//      MVertex *p1 = std::min(std::min(newv1,newv2),v11);
-//      MVertex *p2 = std::min(std::min(newv2,v11),v21);
-//      search.insert ( std::pair<MVertex*,std::pair<MTriangle*,GFace*> > ( p1, std::pair<MTriangle*,GFace*>(new MTriangle(newv1,newv2,v11),fakeFace)));
-//      search.insert ( std::pair<MVertex*,std::pair<MTriangle*,GFace*> > ( p2, std::pair<MTriangle*,GFace*>(new MTriangle(newv2,v11,v21),fakeFace)));
-//       }
-//       else{
-//      res[0] = newv1;
-//      res[1] = newv2;
-//      res[2] = v21;
-//      res[3] = v11;
-//      MVertex *p1 = std::min(std::min(newv1,newv2),v21);
-//      MVertex *p2 = std::min(std::min(newv2,v11),v21);
-//      search.insert ( std::pair<MVertex*,std::pair<MTriangle*,GFace*> > ( p1, std::pair<MTriangle*,GFace*>(new MTriangle(newv1,newv2,v21),fakeFace)));
-//      search.insert ( std::pair<MVertex*,std::pair<MTriangle*,GFace*> > ( p2, std::pair<MTriangle*,GFace*>(new MTriangle(newv1,v11,v21),fakeFace)));
-//       }
-//     }
-//   }
-// }
-// void splitQuadFace (std::vector<MTet4 *> &newTets,
-//                  std::vector<MVertex *> &steinerPoints,
-//                  MVertex* newv1,
-//                  MVertex* newv2,
-//                  MVertex* v21,
-//                  MVertex* v11,
-//                  MVertex* other,
-//                  const qualityMeasure4Tet &cr,
-//                  fs_cont &search,
-//                  GFace *fakeFace){
-//   MTetrahedron *tr3,*tr4;
-//   // now we look if there exists a face with the same vertices
-//   GFace* gfound = findInFaceSearchStructure (newv1,newv2,v11,search);
-//   if (gfound){
-//     tr3 = new MTetrahedron ( newv1,newv2,v11,other);
-//     tr4 = new MTetrahedron ( newv2,v11,v21,other);
-//   }
-//   else{
-//     GFace* gfound = findInFaceSearchStructure (newv1,newv2,v21,search);
-//     if (gfound){
-//       tr3 = new MTetrahedron ( newv1,newv2,v21,other);
-//       tr4 = new MTetrahedron ( newv1,v11,v21,other);
-//     }
-//     // choose the best configuration
-//     else{
-//       double vol;
-//       double q1 = std::min(qmTet(newv1,newv2,v11,other,cr,vol),qmTet(newv2,v11,v21,other,cr,vol));
-//       double q2 = std::min(qmTet(newv1,newv2,v21,other,cr,vol),qmTet(newv1,v11,v21,other,cr,vol));
-//       if (q1 > q2){
-//      tr3 = new MTetrahedron ( newv1,newv2,v11,other);
-//      tr4 = new MTetrahedron ( newv2,v11,v21,other);
-//      MVertex *p1 = std::min(std::min(newv1,newv2),v11);
-//      MVertex *p2 = std::min(std::min(newv2,v11),v21);
-//      search.insert ( std::pair<MVertex*,std::pair<MTriangle*,GFace*> > ( p1, std::pair<MTriangle*,GFace*>(new MTriangle(newv1,newv2,v11),fakeFace)));
-//      search.insert ( std::pair<MVertex*,std::pair<MTriangle*,GFace*> > ( p2, std::pair<MTriangle*,GFace*>(new MTriangle(newv2,v11,v21),fakeFace)));
-//       }
-//       else{
-//      tr3 = new MTetrahedron ( newv1,newv2,v21,other);
-//      tr4 = new MTetrahedron ( newv1,v11,v21,other);
-//      MVertex *p1 = std::min(std::min(newv1,newv2),v21);
-//      MVertex *p2 = std::min(std::min(newv2,v11),v21);
-//      search.insert ( std::pair<MVertex*,std::pair<MTriangle*,GFace*> > ( p1, std::pair<MTriangle*,GFace*>(new MTriangle(newv1,newv2,v21),fakeFace)));
-//      search.insert ( std::pair<MVertex*,std::pair<MTriangle*,GFace*> > ( p2, std::pair<MTriangle*,GFace*>(new MTriangle(newv1,v11,v21),fakeFace)));
-//       }
-//     }
-//   }
-// }
-
-// bool splitEdgesOfTet (std::vector<MTet4 *> &newTets,
-//                    std::vector<MVertex *> &steinerPoints,
-//                    MTet4 *t1,
-//                    int nbEdges,
-//                    int e[6],
-//                    MVertex* pts[6],
-//                    const qualityMeasure4Tet &cr,
-//                    fs_cont &search,
-//                    GFace *fakeFace){
-//   switch(nbEdges){
-//   case 1 :
-//     {
-//       int iE = edges[0];
-//       MVertex *newv = pts[0];
-//       MVertex *v1 = t1->tet()->getVertex(e[iE][0]);
-//       MVertex *v2 = t1->tet()->getVertex(e[iE][1]);
-//       int oE = 5-iE;
-//       MVertex *o1 = t1->tet()->getVertex(e[oE][0]);
-//       MVertex *o2 = t1->tet()->getVertex(e[oE][1]);
-//       MTetrahedron *tr1 = new MTetrahedron ( newv,v1,o1,o2);
-//       MTetrahedron *tr2 = new MTetrahedron ( newv,v2,o2,o1);
-//       MTet4 *t41 = new MTet4 (tr1,cr);
-//       MTet4 *t42 = new MTet4 (tr2,cr);
-//       newTets.push_back(t41);
-//       newTets.push_back(t42);
-//       }
-//     break;
-//   case 2 :
-//     {
-//       int iE1 = edges[0];
-//       int iE2 = edges[1];
-
-//       MVertex *newv1 = pts[0];
-//       MVertex *newv2 = pts[1];
-
-//       MVertex *v11 = t1->tet()->getVertex(e[iE1][0]);
-//       MVertex *v12 = t1->tet()->getVertex(e[iE1][1]);
-//       MVertex *v21 = t1->tet()->getVertex(e[iE2][0]);
-//       MVertex *v22 = t1->tet()->getVertex(e[iE2][1]);
-
-//       if (iE1 == 5-iE2){ // two opposite edges
-//      MTetrahedron *tr1 = new MTetrahedron ( newv1,newv2,v11,v21);
-//      MTetrahedron *tr2 = new MTetrahedron ( newv1,newv2,v21,v12);
-//      MTetrahedron *tr3 = new MTetrahedron ( newv1,newv2,v12,v22);
-//      MTetrahedron *tr4 = new MTetrahedron ( newv1,newv2,v22,v11);
-//      MTet4 *t41 = new MTet4 (tr1,cr);
-//      MTet4 *t42 = new MTet4 (tr2,cr);
-//      MTet4 *t43 = new MTet4 (tr3,cr);
-//      MTet4 *t44 = new MTet4 (tr4,cr);
-//      newTets.push_back(t41);
-//      newTets.push_back(t42);
-//      newTets.push_back(t43);
-//      newTets.push_back(t44);
-//       }
-//       else{ //two adjacend edges
-//      MVertex *vsame,*other=0;
-//      if      (v11 == v21){vsame=v11; v11=v12; v21=v22;}
-//      else if (v11 == v22){vsame=v11; v11=v12}
-//      else if (v12 == v21){vsame=v12; v21=v22}
-//      else if (v12 == v22){vsame=v12;}
-//      else throw;
-//      for (int i=0;i<4;i++){
-//        if (vsame != t1->tet()->getVertex(i) &&
-//            v11 != t1->tet()->getVertex(i) &&
-//            v21 != t1->tet()->getVertex(i)){
-//          other = t1->tet->getVertex(i);
-//          break;
-//        }
-//      }
-//      if (!other)throw;
-//      MTetrahedron *tr1 = new MTetrahedron ( newv1,newv2,vsame,other);
-//      splitQuadFace (newTets,steinerPoints,newv1,newv2,v21,v11,other,cr,search,fakeFace);
-//       }
-//     }
-//     break;
-//   case 3 :
-//     {
-//       int iE1 = edges[0];
-//       int iE2 = edges[1];
-//       int iE3 = edges[2];
-//       MVertex *newv1;
-//       MVertex *newv2;
-//       MVertex *newv3;
-//       std::sort(edges,edges+3);
-//       if (iE1 == edges[0])newv1=pts[0];
-//       else if (iE2 == edges[0])newv1=pts[1];
-//       else if (iE3 == edges[0])newv1=pts[2];
-//       if (iE1 == edges[1])newv2=pts[0];
-//       else if (iE2 == edges[1])newv2=pts[1];
-//       else if (iE3 == edges[1])newv2=pts[2];
-//       if (iE1 == edges[2])newv3=pts[0];
-//       else if (iE2 == edges[2])newv3=pts[1];
-//       else if (iE3 == edges[2])newv3=pts[2];
-//       iE1 = edges[0];
-//       iE2 = edges[1];
-//       iE3 = edges[2];
-//       // edges are sorted and points correspond
-
-//       mVertex *v[4];
-//       // the 3 edges coincide at one vertex
-//       int config;
-//       if (iE1 == 0 && iE2 == 1 && iE3 == 2){
-//      config = 1;
-//      v[0] = t1->tet()->getVertex(0);
-//      v[1] = t1->tet()->getVertex(1);
-//      v[2] = t1->tet()->getVertex(2);
-//      v[3] = t1->tet()->getVertex(3);
-//       }
-//       else if (iE1 == 0 && iE2 == 3 && iE3 == 4){
-//      config = 1;
-//      v[0] = t1->tet()->getVertex(1);
-//      v[1] = t1->tet()->getVertex(0);
-//      v[2] = t1->tet()->getVertex(2);
-//      v[3] = t1->tet()->getVertex(3);
-//       }
-//       else if (iE1 == 1 && iE2 == 3 && iE3 == 5){
-//      config = 1;
-//      v[0] = t1->tet()->getVertex(2);
-//      v[1] = t1->tet()->getVertex(0);
-//      v[2] = t1->tet()->getVertex(1);
-//      v[3] = t1->tet()->getVertex(3);
-//       }
-//       else if (iE1 == 2 && iE2 == 4 && iE3 == 5){
-//      config = 1;
-//      v[0] = t1->tet()->getVertex(3);
-//      v[1] = t1->tet()->getVertex(0);
-//      v[2] = t1->tet()->getVertex(1);
-//      v[3] = t1->tet()->getVertex(2);
-//       }
-//       // three edges of the same face are cut
-//       else if (iE1 == 0 && iE2 == 1 && iE3 == 3){
-//      config = 2;
-//      v[0] = t1->tet()->getVertex(3);
-//      v[1] = t1->tet()->getVertex(1);
-//      v[2] = t1->tet()->getVertex(0);
-//      v[3] = t1->tet()->getVertex(2);
-//       }
-//       else if (iE1 == 0 && iE2 == 2 && iE3 == 4){
-//      config = 2;
-//      v[0] = t1->tet()->getVertex(2);
-//      v[1] = t1->tet()->getVertex(1);
-//      v[2] = t1->tet()->getVertex(0);
-//      v[3] = t1->tet()->getVertex(3);
-//       }
-//       else if (iE1 == 1 && iE2 == 2 && iE3 == 5){
-//      config = 2;
-//      v[0] = t1->tet()->getVertex(1);
-//      v[1] = t1->tet()->getVertex(2);
-//      v[2] = t1->tet()->getVertex(0);
-//      v[3] = t1->tet()->getVertex(3);
-//       }
-//       else if (iE1 == 3 && iE2 == 4 && iE3 == 5){
-//      config = 2;
-//      v[0] = t1->tet()->getVertex(0);
-//      v[1] = t1->tet()->getVertex(2);
-//      v[2] = t1->tet()->getVertex(1);
-//      v[3] = t1->tet()->getVertex(3);
-//       }
-//       // the three edges for a kind of Z
-//       else if (iE1 == 0 && iE2 == 3 && iE3 == 5){
-//      config = 3;
-//       }
-
-//       if (config == 1){
-//       }
-//       else if (config == 2){
-//       }
-//       else{
-//      throw; // for the moment.
-//       }
-//     }
-//   default :
-//     throw;
-//   }
-//   t1->setDeleted(true);
-
-
-// }
-
-
-
-// collapse
