@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2015 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2016 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@geuz.org>.
+// bugs and problems to the public mailing list <gmsh@onelab.info>.
 
 #ifndef _MESH_PARTITION_OPTIONS_H_
 #define _MESH_PARTITION_OPTIONS_H_
@@ -78,6 +78,7 @@ class meshPartitionOptions
   int tetWeight;
   int priWeight;
   int pyrWeight;
+  int trihWeight;
   int hexWeight;
 
   // NODAL WEIGHT
@@ -130,6 +131,7 @@ class meshPartitionOptions
     tetWeight = 1;
     priWeight = 1;
     pyrWeight = 1;
+    trihWeight = 0;
     hexWeight = 1;
   }
 };
