@@ -1,11 +1,16 @@
-// Gmsh - Copyright (C) 1997-2014 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2016 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@geuz.org>.
+// bugs and problems to the public mailing list <gmsh@onelab.info>.
 //
 // Contributor(s):
 //   Tristan Carrier François Henrotte
 
+
+#ifndef _SIMPLE3D_H_
+#define _SIMPLE3D_H_
+
+
 #include "SVector3.h"
 #include <list>
 #include "GRegion.h"
@@ -37,3 +42,6 @@ class Filler{
   static int get_nbr_new_vertices();
   static MVertex* get_new_vertex(int);
 };
+
+#endif
+
