@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2015 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2016 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@geuz.org>.
+// bugs and problems to the public mailing list <gmsh@onelab.info>.
 
 #include "GaussIntegration.h"
 #include "GaussLegendre1D.h"
@@ -69,7 +69,7 @@ IntPt *getGQHPts(int order)
   if(order < 2) return GQH[order];
   if(order == 2) return GQH[3];
   if(order == 3) return GQH[3];
-  int n = (order+3)/2;
+  int n = (order + 1) / (float)2 + 0.5;
   int index = n-2 + 4;
   if(index >= (int)(sizeof(GQH) / sizeof(IntPt*))){
     Msg::Error("Increase size of GQH in gauss quadrature hex");
@@ -100,5 +100,6 @@ int getNGQHPts(int order)
   if(order == 2)return 8;
   if(order < 2)
     return GQHnPt[order];
-  return ((order+3)/2)*((order+3)/2)*((order+3)/2);
+  int n = (order + 1) / (float)2 + 0.5;
+  return n * n * n;
 }
