@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2014 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2016 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@geuz.org>.
+// bugs and problems to the public mailing list <gmsh@onelab.info>.
 
 #include "GaussIntegration.h"
 #include "GaussLegendre1D.h"
@@ -9,12 +9,15 @@
 IntPt * GQL[20] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
 
 IntPt *getGQLPts(int order)
-{  
+{
   // Number of Gauss Point:
   // (order + 1) / 2 *ROUNDED UP*
-
-  int n     = (order + 1) / (double)2 + 0.5;
+  int n = (order + 1) / (double)2 + 0.5;
   int index = n;
+  if(index >= (int)(sizeof(GQL) / sizeof(IntPt*))){
+    Msg::Error("Increase size of GQL in gauss quadrature line");
+    index = 0;
+  }
   if(!GQL[index]) {
     double *pt,*wt;
     gmshGaussLegendre1D(n,&pt,&wt);
@@ -30,6 +33,6 @@ IntPt *getGQLPts(int order)
 }
 
 int getNGQLPts(int order)
-{ 
+{
   return (order + 1) / (double)2 + 0.5;
 }
