@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2015 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2016 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@geuz.org>.
+// bugs and problems to the public mailing list <gmsh@onelab.info>.
 
 #include "GmshMessage.h"
 #include "GaussIntegration.h"
@@ -61,7 +61,7 @@ IntPt *getGQPyrPts(int order)
       GQPyr[index][l].pt[2] = 0.5*(1+wp);
 
       wt *= 0.125;
-      GQPyr[index][l++].weight = wt;
+      GQPyr[index][l++].weight = wt *4./3.;
 
     }
 
