@@ -446,7 +446,8 @@ void JacobianBasis::getJacobianGeneral(int nJacNodes,
                                        const fullMatrix<double> &gSMatZ,
                                        const fullMatrix<double> &nodesXYZ,
                                        bool idealNorm, bool scaling,
-                                       fullVector<double> &jacobian) const
+                                       fullVector<double> &jacobian,
+                                       const fullMatrix<double> *geomNormals) const
 {
   switch (_dim) {
 
@@ -458,11 +459,13 @@ void JacobianBasis::getJacobianGeneral(int nJacNodes,
     case 1 : {
       fullMatrix<double> normals(2,3);
       const double invScale = getPrimNormals1D(nodesXYZ,normals);
-      if (invScale == 0) {
-        for (int i = 0; i < nJacNodes; i++) jacobian(i) = 0;
-        return;
-      }
+      if (geomNormals)
+        normals.setAll(*geomNormals);
       if (scaling) {
+        if (invScale == 0) {
+          for (int i = 0; i < nJacNodes; i++) jacobian(i) = 0;
+          return;
+        }
         const double scale = 1./invScale;
         normals(0,0) *= scale; normals(0,1) *= scale; normals(0,2) *= scale;            // Faster to scale 1 normal than afterwards
       }
@@ -482,6 +485,8 @@ void JacobianBasis::getJacobianGeneral(int nJacNodes,
     case 2 : {
       fullMatrix<double> normal(1,3);
       const double invScale = getPrimNormal2D(nodesXYZ, normal, idealNorm);
+      if (geomNormals)
+        normal.setAll(*geomNormals);
       if (scaling) {
         if (invScale == 0) {
           for (int i = 0; i < nJacNodes; i++) jacobian(i) = 0;
@@ -541,7 +546,8 @@ void JacobianBasis::getJacobianGeneral(int nJacNodes,
                                        const fullMatrix<double> &nodesY,
                                        const fullMatrix<double> &nodesZ,
                                        bool idealNorm, bool scaling,
-                                       fullMatrix<double> &jacobian) const
+                                       fullMatrix<double> &jacobian,
+                                       const fullMatrix<double> *geomNormals) const
 {
   switch (_dim) {
 
@@ -565,11 +571,13 @@ void JacobianBasis::getJacobianGeneral(int nJacNodes,
         }
         fullMatrix<double> normals(2,3);
         const double invScale = getPrimNormals1D(nodesXYZ,normals);
-        if (invScale == 0) {
-          for (int i = 0; i < nJacNodes; i++) jacobian(i,iEl) = 0;
-          continue;
-        }
+        if (geomNormals)
+          normals.setAll(*geomNormals);
         if (scaling) {
+          if (invScale == 0) {
+            for (int i = 0; i < nJacNodes; i++) jacobian(i,iEl) = 0;
+            continue;
+          }
           const double scale = 1./invScale;
           normals(0,0) *= scale; normals(0,1) *= scale; normals(0,2) *= scale;                // Faster to scale 1 normal than afterwards
         }
@@ -598,11 +606,13 @@ void JacobianBasis::getJacobianGeneral(int nJacNodes,
         }
         fullMatrix<double> normal(1,3);
         const double invScale = getPrimNormal2D(nodesXYZ, normal, idealNorm);
-        if (invScale == 0) {
-          for (int i = 0; i < nJacNodes; i++) jacobian(i,iEl) = 0;
-          continue;
-        }
+        if (geomNormals)
+          normal.setAll(*geomNormals);
         if (scaling) {
+          if (invScale == 0) {
+            for (int i = 0; i < nJacNodes; i++) jacobian(i,iEl) = 0;
+            continue;
+          }
           const double scale = 1./invScale;
           normal(0,0) *= scale; normal(0,1) *= scale; normal(0,2) *= scale;                   // Faster to scale normal than afterwards
         }
