@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2015 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2016 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@geuz.org>.
+// bugs and problems to the public mailing list <gmsh@onelab.info>.
 
 #ifndef _PARSER_H_
 #define _PARSER_H_
@@ -30,7 +30,7 @@ extern int gmsh_yyviewindex;
 extern std::string gmsh_yyname;
 extern int gmsh_yyerrorstate;
 extern std::map<std::string, gmsh_yysymbol> gmsh_yysymbols;
-extern std::map<std::string, std::string> gmsh_yystringsymbols;
+extern std::map<std::string, std::vector<std::string> > gmsh_yystringsymbols;
 
 void PrintParserSymbols(bool help, std::vector<std::string> &vec);
 
