@@ -65,6 +65,7 @@
 #include "FaultZone.h"
 #include "MeshSubEntities.h"
 #include "CVTRemesh.h"
+#include "ShowNeighborElements.h"
 
 // for testing purposes only :-)
 #undef HAVE_DLOPEN
@@ -187,8 +188,6 @@ void PluginManager::registerDefaultPlugins()
                       ("Skin", GMSH_RegisterSkinPlugin()));
     allPlugins.insert(std::pair<std::string, GMSH_Plugin*>
                       ("MathEval", GMSH_RegisterMathEvalPlugin()));
-    allPlugins.insert(std::pair<std::string, GMSH_Plugin*>
-                      ("AnalyseCurvedMesh", GMSH_RegisterAnalyseCurvedMeshPlugin()));
     allPlugins.insert(std::pair<std::string, GMSH_Plugin*>
                       ("CurvedBndDist", GMSH_RegisterCurvedBndDistPlugin()));
     allPlugins.insert(std::pair<std::string, GMSH_Plugin*>
@@ -263,8 +262,14 @@ void PluginManager::registerDefaultPlugins()
                       ("DuplicateBoundaries", GMSH_RegisterDuplicateBoundariesPlugin()));
     allPlugins.insert(std::pair<std::string, GMSH_Plugin*>
                       ("ThinLayerFixMesh", GMSH_RegisterThinLayerFixMeshPlugin()));
+    allPlugins.insert(std::pair<std::string, GMSH_Plugin*>
+                      ("ShowNeighborElements", GMSH_RegisterShowNeighborElementsPlugin()));
     allPlugins.insert(std::pair<std::string, GMSH_Plugin*>
                       ("MeshSubEntities", GMSH_RegisterMeshSubEntitiesPlugin()));
+#if defined(HAVE_MESH)
+    allPlugins.insert(std::pair<std::string, GMSH_Plugin*>
+                      ("AnalyseCurvedMesh", GMSH_RegisterAnalyseCurvedMeshPlugin()));
+#endif
 #if defined(HAVE_REVOROPT)
     allPlugins.insert(std::pair<std::string, GMSH_Plugin*>
                       ("CVTRemesh", GMSH_RegisterCVTRemeshPlugin()));
