@@ -26,53 +26,66 @@
 #endif
 
 /*
-static void printLinearSystem(linearSystemCSRTaucs<double> *lsys)
+static void printLinearSystem(linearSystem<double> *lsys, int size)
 {
-  int *startIndex;
-  int *columns;
-  double *values;
-  lsys->getMatrix(startIndex, columns, values);
-  for(int i = 0; i < lsys->getNbUnk(); i++){
-    std::cout<<"a ";
-    for(int j = 0; j < lsys->getNbUnk(); j++){
-      double val = 0.;
-      for(int k = startIndex[i]; k < startIndex[i+1]; k++){
-        if(columns[k] == j) {val = values[k]; break;}
-      }
-      std::cout<< val <<" ";
+  if(!lsys->isAllocated()){printf("Linear system not allocated\n"); return;}
+  double valeur;
+  printf("K\n");
+  for (int i = 0; i < size; i++){
+    for (int j = 0; j < size; j++ ){
+      lsys->getFromMatrix (i, j, valeur);
+      printf ("%g ", valeur) ;
     }
-    std::cout<<std::endl;
-  }std::cout<<std::endl;
-  for(int i = 0; i < lsys->getNbUnk(); i++) {
-    double val; lsys->getFromRightHandSide(i,val);
-    std::cout<<"b "<<val<<std::endl;
-  }std::cout<<std::endl;
-  for(int i = 0; i < lsys->getNbUnk(); i++) {
-    double val; lsys->getFromSolution(i,val);
-    std::cout<<"x "<<val<<std::endl;
+    printf("\n");
+  }
+  printf("b\n");
+  for (int i = 0; i < size; i++){
+    lsys->getFromRightHandSide(i, valeur);
+    printf("%g\n", valeur);
+  }
+  printf("x\n");
+  for (int i = 0; i < size; i++){
+    lsys->getFromSolution(i, valeur);
+    printf("%g\n", valeur);
   }
 }
 */
 
-void elasticitySolver::setMesh(const std::string &meshFileName)
+elasticitySolver::elasticitySolver(GModel *model, int tag)
+{
+  pModel = model;
+  _dim = pModel->getNumRegions() ? 3 : 2;
+  _tag = tag;
+  pAssembler = NULL;
+  if (_dim==3) LagSpace=new VectorLagrangeFunctionSpace(_tag);
+  if (_dim==2) LagSpace=new VectorLagrangeFunctionSpace(_tag,
+                VectorLagrangeFunctionSpace::VECTOR_X,
+                VectorLagrangeFunctionSpace::VECTOR_Y);
+}
+
+void elasticitySolver::setMesh(const std::string &meshFileName, int dim)
 {
   pModel = new GModel();
   pModel->readMSH(meshFileName.c_str());
   _dim = pModel->getNumRegions() ? 3 : 2;
 
   if (LagSpace) delete LagSpace;
-  if (_dim==3) LagSpace = new VectorLagrangeFunctionSpace(_tag);
-  if (_dim==2) LagSpace = new VectorLagrangeFunctionSpace
+  if (dim == 3 || _dim==3) LagSpace = new VectorLagrangeFunctionSpace(_tag);
+  else if (dim == 2 || _dim==2) LagSpace = new VectorLagrangeFunctionSpace
                  (_tag,VectorLagrangeFunctionSpace::VECTOR_X,
                   VectorLagrangeFunctionSpace::VECTOR_Y);
 
-  if (LagrangeMultiplierSpace) delete LagrangeMultiplierSpace;
-  LagrangeMultiplierSpace = new ScalarLagrangeFunctionSpace(_tag+1);
+  for (unsigned int i = 0; i < LagrangeMultiplierSpaces.size(); i++)
+    if (LagrangeMultiplierSpaces[i]) delete LagrangeMultiplierSpaces[i];
+  LagrangeMultiplierSpaces.clear();
 }
 
 void elasticitySolver::exportKb()
 {
   std::string sysname = "A";
+  if(!pAssembler ||
+     !pAssembler->getLinearSystem(sysname) ||
+     !pAssembler->getLinearSystem(sysname)->isAllocated()) return;
   double valeur;
   FILE *f = Fopen("K.txt", "w");
   if(f){
@@ -97,9 +110,11 @@ void elasticitySolver::exportKb()
 
 void elasticitySolver::solve()
 {
+  std::string sysname = "A";
+  if(pAssembler && pAssembler->getLinearSystem(sysname))
+    delete pAssembler->getLinearSystem(sysname);
 
   //linearSystemFull<double> *lsys = new linearSystemFull<double>;
-
 #if defined(HAVE_TAUCS)
   linearSystemCSRTaucs<double> *lsys = new linearSystemCSRTaucs<double>;
 #elif defined(HAVE_PETSC)
@@ -110,13 +125,12 @@ void elasticitySolver::solve()
 #endif
 
   assemble(lsys);
+  //printLinearSystem(lsys,pAssembler->sizeOfR());
   lsys->systemSolve();
   printf("-- done solving!\n");
-  GaussQuadrature Integ_Bulk(GaussQuadrature::GradGrad);
-
-//   printLinearSystem(lsys);
 
   double energ=0;
+  GaussQuadrature Integ_Bulk(GaussQuadrature::GradGrad);
   for (unsigned int i = 0; i < elasticFields.size(); i++){
     SolverField<SVector3> Field(pAssembler, LagSpace);
     IsotropicElasticTerm Eterm(Field,elasticFields[i]._E,elasticFields[i]._nu);
@@ -157,7 +171,8 @@ void elasticitySolver::readInputFile(const std::string &fn)
     }
     if(what[0]=='#'){
       char buffer[1024];
-      fgets(buffer, sizeof(buffer), f);
+      if(fgets(buffer, sizeof(buffer), f) == NULL) 
+        Msg::Error("Cannot read line.");
     }
     else if (!strcmp(what, "ElasticDomain")){
       elasticField field;
@@ -179,11 +194,12 @@ void elasticitySolver::readInputFile(const std::string &fn)
         fclose(f);
         return;
       }
-      field._tag = _tag;
-      field._d = SVector3(d1, d2, d3);
+      SVector3 sv(d1, d2, d3);
+      field._d = sv.unit();
       field._f = new simpleFunction<double>(val);
       field.g = new groupOfElements (_dim - 1, physical);
       LagrangeMultiplierFields.push_back(field);
+      LagrangeMultiplierSpaces.push_back(new ScalarLagrangeFunctionSpaceOfElement(field._tag));
     }
     else if (!strcmp(what, "Void")){
       elasticField field;
@@ -348,6 +364,57 @@ void elasticitySolver::readInputFile(const std::string &fn)
 }
 
 
+void elasticitySolver::cutMesh(gLevelset *ls)
+{
+  pModel = pModel->buildCutGModel(ls);
+  pModel->writeMSH("cutMesh.msh");
+}
+
+void elasticitySolver::setElasticDomain(int phys, double E, double nu)
+{
+  elasticField field;
+  field._E = E;
+  field._nu = nu;
+  field._tag = _tag;
+  field.g = new groupOfElements (_dim, phys);
+  elasticFields.push_back(field);
+}
+
+void elasticitySolver::setLagrangeMultipliers(int phys, double tau, SVector3 d,
+                                              int tag, simpleFunction<double> *f)
+{
+  LagrangeMultiplierField field;
+  field._tau = tau;
+  field._tag = tag;
+  field._f = f;
+  field._d = d.unit();
+  field.g = new groupOfElements (_dim - 1, phys); // LM applied on entity of dimension = dim-1!
+  LagrangeMultiplierFields.push_back(field);
+  LagrangeMultiplierSpaces.push_back(new ScalarLagrangeFunctionSpaceOfElement(tag));
+}
+
+void elasticitySolver::changeLMTau(int tag, double tau)
+{
+  for(unsigned int i = 0; i < LagrangeMultiplierFields.size(); i++){
+    if(LagrangeMultiplierFields[i]._tag == tag){
+      LagrangeMultiplierFields[i]._tau = tau;
+    }
+  }
+  
+}
+
+void elasticitySolver::setEdgeDisp(int edge, int comp, simpleFunction<double> *f)
+{
+  dirichletBC diri;
+  diri.g = new groupOfElements (1, edge);
+  diri._f = f;
+  diri._comp = comp;
+  diri._tag = edge;
+  diri.onWhat = BoundaryCondition::ON_EDGE;
+  allDirichlet.push_back(diri);
+}
+
+
 void elasticitySolver::addDirichletBC(int dim, int entityId, int component, double value)
 {
   dirichletBC diri;
@@ -408,19 +475,6 @@ void elasticitySolver::addElasticDomain(std::string phys, double e, double nu)
   addElasticDomain(entityId, e, nu);
 }
 
-elasticitySolver::elasticitySolver(GModel *model, int tag)
-{
-  pModel = model;
-  _dim = pModel->getNumRegions() ? 3 : 2;
-  _tag = tag;
-  pAssembler = NULL;
-  if (_dim==3) LagSpace=new VectorLagrangeFunctionSpace(_tag);
-  if (_dim==2) LagSpace=new VectorLagrangeFunctionSpace(_tag,
-                VectorLagrangeFunctionSpace::VECTOR_X,
-                VectorLagrangeFunctionSpace::VECTOR_Y);
-  LagrangeMultiplierSpace = new ScalarLagrangeFunctionSpace(_tag+1);
-}
-
 void elasticitySolver::assemble(linearSystem<double> *lsys)
 {
   if (pAssembler) delete pAssembler;
@@ -438,7 +492,10 @@ void elasticitySolver::assemble(linearSystem<double> *lsys)
   }
   // LagrangeMultipliers
   for (unsigned int i = 0; i < LagrangeMultiplierFields.size(); ++i){
-    NumberDofs(*LagrangeMultiplierSpace, LagrangeMultiplierFields[i].g->begin(),
+    unsigned int j = 0;
+    for ( ; j < LagrangeMultiplierSpaces.size(); j++)
+      if (LagrangeMultiplierSpaces[j]->getId() == LagrangeMultiplierFields[i]._tag) break;
+    NumberDofs(*(LagrangeMultiplierSpaces[j]), LagrangeMultiplierFields[i].g->begin(),
                LagrangeMultiplierFields[i].g->end(), *pAssembler);
   }
   // Elastic Fields
@@ -465,38 +522,36 @@ void elasticitySolver::assemble(linearSystem<double> *lsys)
   GaussQuadrature Integ_LagrangeMult(GaussQuadrature::ValVal);
   GaussQuadrature Integ_Laplace(GaussQuadrature::GradGrad);
   for (unsigned int i = 0; i < LagrangeMultiplierFields.size(); i++){
-    LagrangeMultiplierTerm<SVector3> LagTerm(*LagSpace, *LagrangeMultiplierSpace,
+    unsigned int j = 0;
+    for ( ; j < LagrangeMultiplierSpaces.size(); j++)
+      if (LagrangeMultiplierSpaces[j]->getId() == LagrangeMultiplierFields[i]._tag) break;
+    printf("Lagrange Mult Lag\n");
+    LagrangeMultiplierTerm<SVector3> LagTerm(*LagSpace, *(LagrangeMultiplierSpaces[j]),
                                              LagrangeMultiplierFields[i]._d);
-    Assemble(LagTerm, *LagSpace, *LagrangeMultiplierSpace,
+    Assemble(LagTerm, *LagSpace, *(LagrangeMultiplierSpaces[j]),
              LagrangeMultiplierFields[i].g->begin(),
              LagrangeMultiplierFields[i].g->end(), Integ_LagrangeMult, *pAssembler);
 
-    LaplaceTerm<double,double> LapTerm(*LagrangeMultiplierSpace,
-                                       LagrangeMultiplierFields[i]._tau);
-    Assemble(LapTerm, *LagrangeMultiplierSpace, LagrangeMultiplierFields[i].g->begin(),
+    printf("Lagrange Mult Lap\n");
+    LaplaceTerm<double,double> LapTerm(*(LagrangeMultiplierSpaces[j]),
+                                       -LagrangeMultiplierFields[i]._tau);
+    Assemble(LapTerm, *(LagrangeMultiplierSpaces[j]), LagrangeMultiplierFields[i].g->begin(),
              LagrangeMultiplierFields[i].g->end(), Integ_Laplace, *pAssembler);
 
-    LoadTerm<double> Lterm(*LagrangeMultiplierSpace, LagrangeMultiplierFields[i]._f);
-    Assemble(Lterm, *LagrangeMultiplierSpace, LagrangeMultiplierFields[i].g->begin(),
+    printf("Lagrange Mult Load\n");
+    LoadTermOnBorder<double> Lterm(*(LagrangeMultiplierSpaces[j]), LagrangeMultiplierFields[i]._f);
+    Assemble(Lterm, *(LagrangeMultiplierSpaces[j]), LagrangeMultiplierFields[i].g->begin(),
              LagrangeMultiplierFields[i].g->end(), Integ_Boundary, *pAssembler);
   }
   // Assemble elastic term for
   GaussQuadrature Integ_Bulk(GaussQuadrature::GradGrad);
   for (unsigned int i = 0; i < elasticFields.size(); i++){
+    printf("Elastic\n");
     IsotropicElasticTerm Eterm(*LagSpace,elasticFields[i]._E,elasticFields[i]._nu);
     Assemble(Eterm, *LagSpace, elasticFields[i].g->begin(), elasticFields[i].g->end(),
              Integ_Bulk, *pAssembler);
   }
 
-  /*for (int i=0;i<pAssembler->sizeOfR();i++){
-    for (int j=0;j<pAssembler->sizeOfR();j++){
-      double d;lsys->getFromMatrix(i,j,d);
-      printf("%12.5E ",d);
-    }
-    double d;lsys->getFromRightHandSide(i,d);
-    printf(" |  %12.5E\n",d);
-  }*/
-
   printf("nDofs=%d\n",pAssembler->sizeOfR());
   printf("nFixed=%d\n",pAssembler->sizeOfF());
 
@@ -606,8 +661,134 @@ void elasticitySolver::computeEffectiveStrain(std::vector<double> strain)
     strain[i] = st[i] / volTot;
 }
 
+double elasticitySolver::computeDisplacementError(simpleFunction<double> *f0, simpleFunction<double> *f1,
+                                                  simpleFunction<double> *f2) {
+  std::cout <<  "compute displacement error"<< std::endl;
+  double err = 0.;
+  std::set<MVertex*> v;
+  std::map<MVertex*, MElement*> vCut;
+  for (unsigned int i = 0; i < elasticFields.size(); ++i){
+    if(elasticFields[i]._E == 0.) continue;
+    for (groupOfElements::elementContainer::const_iterator it = elasticFields[i].g->begin();
+         it != elasticFields[i].g->end(); ++it){
+      MElement *e = *it;
+      if(e->getParent()) {
+        for (int j = 0; j < e->getNumVertices(); ++j) {
+          if(vCut.find(e->getVertex(j)) == vCut.end())
+            vCut[e->getVertex(j)] = e->getParent();
+        }
+      }
+      else {
+        for (int j = 0; j < e->getNumVertices(); ++j)
+          v.insert(e->getVertex(j));
+      }
+    }
+  }
+  SolverField<SVector3> Field(pAssembler, LagSpace);
+  for (std::set<MVertex*>::iterator it = v.begin(); it != v.end(); ++it){
+    SVector3 val;
+    MPoint p(*it);
+    Field.f(&p, 0, 0, 0, val);
+    SVector3 sol((*f0)((*it)->x(), (*it)->y(), (*it)->z()), (*f1)((*it)->x(), (*it)->y(), (*it)->z()),
+                 (*f2)((*it)->x(), (*it)->y(), (*it)->z()));
+    double diff = normSq(sol - val);
+    err += diff;
+  }
+  for (std::map<MVertex*,MElement*>::iterator it = vCut.begin(); it != vCut.end(); ++it){
+    SVector3 val;
+    double uvw[3];
+    double xyz[3] = {it->first->x(), it->first->y(), it->first->z()};
+    it->second->xyz2uvw(xyz, uvw);
+    Field.f(it->second, uvw[0], uvw[1], uvw[2], val);
+    SVector3 sol((*f0)(xyz[0], xyz[1], xyz[2]), (*f1)(xyz[0], xyz[1], xyz[2]),
+                 (*f2)(xyz[0], xyz[1], xyz[2]));
+    double diff = normSq(sol - val);
+    err += diff;
+  }
+printf("Displacement Error = %g\n",sqrt(err));
+  return sqrt(err);
+}
+
+double elasticitySolver::computeL2Norm(simpleFunction<double> *f0, simpleFunction<double> *f1,
+                                       simpleFunction<double> *f2) {
+  double val = 0.0;
+  SolverField<SVector3> solField(pAssembler, LagSpace);
+  for (unsigned int i = 0; i < elasticFields.size(); ++i){
+    for (groupOfElements::elementContainer::const_iterator it = elasticFields[i].g->begin(); it != elasticFields[i].g->end(); ++it){
+      MElement *e = *it;
+      int npts;
+      IntPt *GP;
+      double jac[3][3];
+      int integrationOrder = 2 * (e->getPolynomialOrder()+5);
+      e->getIntegrationPoints(integrationOrder, &npts, &GP);
+      for (int j = 0; j < npts; j++){
+        double u = GP[j].pt[0];
+        double v = GP[j].pt[1];
+        double w = GP[j].pt[2];
+        double weight = GP[j].weight;
+        double detJ = fabs(e->getJacobian (u, v, w, jac));
+        SPoint3 p;
+        e->pnt(u, v, w, p);
+	SVector3 FEMVALUE;
+	solField.f(e, u, v, w, FEMVALUE);
+        SVector3 sol((*f0)(p.x(), p.y(), p.z()), (*f1)(p.x(), p.y(), p.z()),
+                     (*f2)(p.x(), p.y(), p.z()));
+        double diff = normSq(sol - FEMVALUE);
+        val += diff * detJ * weight;
+      }
+    }
+  }
+printf("L2Norm = %g\n",sqrt(val));
+  return sqrt(val);
+}
+
+double elasticitySolver::computeLagNorm(int tag, simpleFunction<double> *sol) {
+  return 0;
+}
+
 #if defined(HAVE_POST)
 
+PView *elasticitySolver::buildErrorView(const std::string postFileName, simpleFunction<double> *f0,
+                                        simpleFunction<double> *f1, simpleFunction<double> *f2)
+{
+  std::cout <<  "build Error View"<< std::endl;
+  std::map<int, std::vector<double> > data;
+  
+  SolverField<SVector3> solField(pAssembler, LagSpace);
+  for (unsigned int i = 0; i < elasticFields.size(); ++i){
+    for (groupOfElements::elementContainer::const_iterator it = elasticFields[i].g->begin(); it != elasticFields[i].g->end(); ++it){
+      MElement *e = *it;
+      int npts;
+      IntPt *GP;
+      double jac[3][3];
+      int integrationOrder = 2 * (e->getPolynomialOrder()+5);
+      e->getIntegrationPoints(integrationOrder, &npts, &GP);
+      double val = 0.0;
+      for (int j = 0; j < npts; j++){
+        double u = GP[j].pt[0];
+        double v = GP[j].pt[1];
+        double w = GP[j].pt[2];
+        double weight = GP[j].weight;
+        double detJ = fabs(e->getJacobian (u, v, w, jac));
+        SPoint3 p;
+        e->pnt(u, v, w, p);
+	SVector3 FEMVALUE;
+	solField.f(e, u, v, w, FEMVALUE);
+        SVector3 sol((*f0)(p.x(), p.y(), p.z()), (*f1)(p.x(), p.y(), p.z()),
+                     (*f2)(p.x(), p.y(), p.z()));
+        double diff = normSq(sol - FEMVALUE);
+        val += diff * detJ * weight;
+      }
+      std::vector<double> vec;
+      vec.push_back(sqrt(val));
+      data[e->getNum()] = vec;
+    }
+  }
+
+  PView *pv = new PView (postFileName, "ElementData", pModel, data, 0.0, 1);
+  return pv;
+}
+
 PView* elasticitySolver::buildDisplacementView (const std::string postFileName)
 {
   std::cout <<  "build Displacement View"<< std::endl;
@@ -784,10 +965,14 @@ PView* elasticitySolver::buildStrainView (const std::string postFileName)
   return pv;
 }
 
-PView* elasticitySolver::buildLagrangeMultiplierView (const std::string postFileName)
+PView* elasticitySolver::buildLagrangeMultiplierView (const std::string postFileName, int tag)
 {
   std::cout <<  "build Lagrange Multiplier View"<< std::endl;
-  if(!LagrangeMultiplierSpace) return new PView();
+  unsigned int t = 0;
+  if(tag != -1)
+    for ( ; t < LagrangeMultiplierSpaces.size(); t++)
+      if (LagrangeMultiplierSpaces[t]->getId() == tag) break;
+  if(t == LagrangeMultiplierSpaces.size()) return new PView();
   std::set<MVertex*> v;
   for (unsigned int i = 0; i < LagrangeMultiplierFields.size(); ++i){
     for(groupOfElements::elementContainer::const_iterator it =
@@ -798,7 +983,7 @@ PView* elasticitySolver::buildLagrangeMultiplierView (const std::string postFile
     }
   }
   std::map<int, std::vector<double> > data;
-  SolverField<double> Field(pAssembler, LagrangeMultiplierSpace);
+  SolverField<double> Field(pAssembler, LagrangeMultiplierSpaces[t]);
   for(std::set<MVertex*>::iterator it = v.begin(); it != v.end(); ++it){
     double val;
     MPoint p(*it);
@@ -908,6 +1093,13 @@ PView *elasticitySolver::buildVonMisesView(const std::string postFileName)
 
 #else
 
+PView* elasticitySolver::buildErrorView(int comp, simpleFunction<double> *sol,
+                                        const std::string postFileName)
+{
+  Msg::Error("Post-pro module not available");
+  return 0;
+}
+
 PView* elasticitySolver::buildDisplacementView(const std::string postFileName)
 {
   Msg::Error("Post-pro module not available");
