@@ -67,12 +67,13 @@ class FunctionSpaceBase
 {
  public:
   virtual ~FunctionSpaceBase(){}
+	virtual int getId(void) const =0;
   virtual int getNumKeys(MElement *ele) = 0; // if one needs the number of dofs
   virtual void getKeys(MElement *ele, std::vector<Dof> &keys) = 0;
   virtual void getKeysOnVertex(MElement* ele, MVertex* v, const std::vector<int>& comp, std::vector<Dof>& keys){
     Msg::Warning("this function is defined to get Dofs of vertex %d on element %d",v->getNum(),ele->getNum());
   }
-  virtual FunctionSpaceBase* clone(const std::vector<int>& comp) const {return NULL;}
+	virtual FunctionSpaceBase* clone(const int id) const {return NULL;}; // copy space with new Id
 };
 
 template<class T>
