@@ -29,10 +29,10 @@
 //  $Header: /cvs/netgen/netgen/libsrc/occ/Partition_Inter3d.cxx,v 1.6 2008/03/31 14:20:28 wabro Exp $
 
 //using namespace std;
-#if !defined(HAVE_NO_OCC_CONFIG_H)
+#include <Standard_Version.hxx>
+#if !defined(HAVE_NO_OCC_CONFIG_H) && (OCC_VERSION_MAJOR < 7)
 #include <config.h>
 #endif
-#include <Standard_Version.hxx>
 
 //using namespace std;
 #include <climits>
