@@ -1,8 +1,8 @@
 #import <UIKit/UIKit.h>
-
+#import <MessageUI/MessageUI.h>
 #import "EAGLView.h"
 
-@interface ModelListController : UITableViewController <NSXMLParserDelegate, UIActionSheetDelegate>
+@interface ModelListController : UITableViewController <NSXMLParserDelegate, MFMailComposeViewControllerDelegate>
 {
     @private
     NSMutableArray *models;
@@ -10,6 +10,8 @@
     NSMutableString *currentElementValue;
     NSString *currentDir;
     NSString *selectedModel;
+    NSString *currentFileToEdit;
 }
 @property (nonatomic, retain) EAGLView *glView;
+
 @end
